# This file is generated by objective.metadata
#
# Last update: Sun Nov 15 11:43:04 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:
    def sel32or64(a, b): return b
else:
    def sel32or64(a, b): return a

misc = {
}
misc.update({'CMTime': objc.createStructType('CMTime', b'{_CMTime=qiIq}', ['value', 'timescale', 'flags', 'epoch']), 'CMTimeMapping': objc.createStructType('CMTimeMapping', b'{_CMTimeMapping={_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}}', ['source', 'target']), 'CMVideoDimensions': objc.createStructType('CMVideoDimensions', b'{_CMVideoDimensions=ii}', ['width', 'height']), 'CMTimeRange': objc.createStructType('CMTimeRange', b'{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}', ['start', 'duration']), 'CMSampleTimingInfo': objc.createStructType('CMSampleTimingInfo', b'{_CMSampleTimingInfo={_CMTime=qiIq}{_CMTime=qiIq}{_CMTime=qiIq}}', ['duration', 'presentationTimeStamp', 'decodeTimeStamp'])})
constants = '''$kCMFormatDescriptionAlphaChannelMode_PremultipliedAlpha$kCMFormatDescriptionAlphaChannelMode_StraightAlpha$kCMFormatDescriptionChromaLocation_Bottom$kCMFormatDescriptionChromaLocation_BottomLeft$kCMFormatDescriptionChromaLocation_Center$kCMFormatDescriptionChromaLocation_DV420$kCMFormatDescriptionChromaLocation_Left$kCMFormatDescriptionChromaLocation_Top$kCMFormatDescriptionChromaLocation_TopLeft$kCMFormatDescriptionColorPrimaries_DCI_P3$kCMFormatDescriptionColorPrimaries_EBU_3213$kCMFormatDescriptionColorPrimaries_ITU_R_2020$kCMFormatDescriptionColorPrimaries_ITU_R_709_2$kCMFormatDescriptionColorPrimaries_P22$kCMFormatDescriptionColorPrimaries_P3_D65$kCMFormatDescriptionColorPrimaries_SMPTE_C$kCMFormatDescriptionConformsToMPEG2VideoProfile$kCMFormatDescriptionExtensionKey_MetadataKeyTable$kCMFormatDescriptionExtension_AlphaChannelMode$kCMFormatDescriptionExtension_AlternativeTransferCharacteristics$kCMFormatDescriptionExtension_AuxiliaryTypeInfo$kCMFormatDescriptionExtension_BytesPerRow$kCMFormatDescriptionExtension_ChromaLocationBottomField$kCMFormatDescriptionExtension_ChromaLocationTopField$kCMFormatDescriptionExtension_CleanAperture$kCMFormatDescriptionExtension_ColorPrimaries$kCMFormatDescriptionExtension_ContainsAlphaChannel$kCMFormatDescriptionExtension_ContentLightLevelInfo$kCMFormatDescriptionExtension_Depth$kCMFormatDescriptionExtension_FieldCount$kCMFormatDescriptionExtension_FieldDetail$kCMFormatDescriptionExtension_FormatName$kCMFormatDescriptionExtension_FullRangeVideo$kCMFormatDescriptionExtension_GammaLevel$kCMFormatDescriptionExtension_ICCProfile$kCMFormatDescriptionExtension_MasteringDisplayColorVolume$kCMFormatDescriptionExtension_OriginalCompressionSettings$kCMFormatDescriptionExtension_PixelAspectRatio$kCMFormatDescriptionExtension_ProtectedContentOriginalFormat$kCMFormatDescriptionExtension_RevisionLevel$kCMFormatDescriptionExtension_SampleDescriptionExtensionAtoms$kCMFormatDescriptionExtension_SpatialQuality$kCMFormatDescriptionExtension_TemporalQuality$kCMFormatDescriptionExtension_TransferFunction$kCMFormatDescriptionExtension_Vendor$kCMFormatDescriptionExtension_VerbatimISOSampleEntry$kCMFormatDescriptionExtension_VerbatimImageDescription$kCMFormatDescriptionExtension_VerbatimSampleDescription$kCMFormatDescriptionExtension_Version$kCMFormatDescriptionExtension_YCbCrMatrix$kCMFormatDescriptionFieldDetail_SpatialFirstLineEarly$kCMFormatDescriptionFieldDetail_SpatialFirstLineLate$kCMFormatDescriptionFieldDetail_TemporalBottomFirst$kCMFormatDescriptionFieldDetail_TemporalTopFirst$kCMFormatDescriptionKey_CleanApertureHeight$kCMFormatDescriptionKey_CleanApertureHeightRational$kCMFormatDescriptionKey_CleanApertureHorizontalOffset$kCMFormatDescriptionKey_CleanApertureHorizontalOffsetRational$kCMFormatDescriptionKey_CleanApertureVerticalOffset$kCMFormatDescriptionKey_CleanApertureVerticalOffsetRational$kCMFormatDescriptionKey_CleanApertureWidth$kCMFormatDescriptionKey_CleanApertureWidthRational$kCMFormatDescriptionKey_PixelAspectRatioHorizontalSpacing$kCMFormatDescriptionKey_PixelAspectRatioVerticalSpacing$kCMFormatDescriptionTransferFunction_ITU_R_2020$kCMFormatDescriptionTransferFunction_ITU_R_2100_HLG$kCMFormatDescriptionTransferFunction_ITU_R_709_2$kCMFormatDescriptionTransferFunction_Linear$kCMFormatDescriptionTransferFunction_SMPTE_240M_1995$kCMFormatDescriptionTransferFunction_SMPTE_ST_2084_PQ$kCMFormatDescriptionTransferFunction_SMPTE_ST_428_1$kCMFormatDescriptionTransferFunction_UseGamma$kCMFormatDescriptionTransferFunction_sRGB$kCMFormatDescriptionVendor_Apple$kCMFormatDescriptionYCbCrMatrix_ITU_R_2020$kCMFormatDescriptionYCbCrMatrix_ITU_R_601_4$kCMFormatDescriptionYCbCrMatrix_ITU_R_709_2$kCMFormatDescriptionYCbCrMatrix_SMPTE_240M_1995$kCMHEVCTemporalLevelInfoKey_ConstraintIndicatorFlags$kCMHEVCTemporalLevelInfoKey_LevelIndex$kCMHEVCTemporalLevelInfoKey_ProfileCompatibilityFlags$kCMHEVCTemporalLevelInfoKey_ProfileIndex$kCMHEVCTemporalLevelInfoKey_ProfileSpace$kCMHEVCTemporalLevelInfoKey_TemporalLevel$kCMHEVCTemporalLevelInfoKey_TierFlag$kCMImageDescriptionFlavor_3GPFamily$kCMImageDescriptionFlavor_ISOFamily$kCMImageDescriptionFlavor_QuickTimeMovie$kCMMemoryPoolOption_AgeOutPeriod$kCMMetadataBaseDataType_AffineTransformF64$kCMMetadataBaseDataType_BMP$kCMMetadataBaseDataType_DimensionsF32$kCMMetadataBaseDataType_Float32$kCMMetadataBaseDataType_Float64$kCMMetadataBaseDataType_GIF$kCMMetadataBaseDataType_JPEG$kCMMetadataBaseDataType_JSON$kCMMetadataBaseDataType_PNG$kCMMetadataBaseDataType_PerspectiveTransformF64$kCMMetadataBaseDataType_PointF32$kCMMetadataBaseDataType_PolygonF32$kCMMetadataBaseDataType_PolylineF32$kCMMetadataBaseDataType_RawData$kCMMetadataBaseDataType_RectF32$kCMMetadataBaseDataType_SInt16$kCMMetadataBaseDataType_SInt32$kCMMetadataBaseDataType_SInt64$kCMMetadataBaseDataType_SInt8$kCMMetadataBaseDataType_UInt16$kCMMetadataBaseDataType_UInt32$kCMMetadataBaseDataType_UInt64$kCMMetadataBaseDataType_UInt8$kCMMetadataBaseDataType_UTF16$kCMMetadataBaseDataType_UTF8$kCMMetadataDataType_QuickTimeMetadataDirection$kCMMetadataDataType_QuickTimeMetadataLocation_ISO6709$kCMMetadataFormatDescriptionKey_ConformingDataTypes$kCMMetadataFormatDescriptionKey_DataType$kCMMetadataFormatDescriptionKey_DataTypeNamespace$kCMMetadataFormatDescriptionKey_LanguageTag$kCMMetadataFormatDescriptionKey_LocalID$kCMMetadataFormatDescriptionKey_Namespace$kCMMetadataFormatDescriptionKey_SetupData$kCMMetadataFormatDescriptionKey_StructuralDependency$kCMMetadataFormatDescriptionKey_Value$kCMMetadataFormatDescriptionMetadataSpecificationKey_DataType$kCMMetadataFormatDescriptionMetadataSpecificationKey_ExtendedLanguageTag$kCMMetadataFormatDescriptionMetadataSpecificationKey_Identifier$kCMMetadataFormatDescriptionMetadataSpecificationKey_SetupData$kCMMetadataFormatDescriptionMetadataSpecificationKey_StructuralDependency$kCMMetadataFormatDescription_StructuralDependencyKey_DependencyIsInvalidFlag$kCMMetadataIdentifier_QuickTimeMetadataDirection_Facing$kCMMetadataIdentifier_QuickTimeMetadataLivePhotoStillImageTransform$kCMMetadataIdentifier_QuickTimeMetadataLivePhotoStillImageTransformReferenceDimensions$kCMMetadataIdentifier_QuickTimeMetadataLocation_ISO6709$kCMMetadataIdentifier_QuickTimeMetadataPreferredAffineTransform$kCMMetadataIdentifier_QuickTimeMetadataVideoOrientation$kCMMetadataKeySpace_HLSDateRange$kCMMetadataKeySpace_ID3$kCMMetadataKeySpace_ISOUserData$kCMMetadataKeySpace_Icy$kCMMetadataKeySpace_QuickTimeMetadata$kCMMetadataKeySpace_QuickTimeUserData$kCMMetadataKeySpace_iTunes$kCMSampleAttachmentKey_AudioIndependentSampleDecoderRefreshCount$kCMSampleAttachmentKey_DependsOnOthers$kCMSampleAttachmentKey_DisplayImmediately$kCMSampleAttachmentKey_DoNotDisplay$kCMSampleAttachmentKey_EarlierDisplayTimesAllowed$kCMSampleAttachmentKey_HEVCStepwiseTemporalSubLayerAccess$kCMSampleAttachmentKey_HEVCSyncSampleNALUnitType$kCMSampleAttachmentKey_HEVCTemporalLevelInfo$kCMSampleAttachmentKey_HEVCTemporalSubLayerAccess$kCMSampleAttachmentKey_HasRedundantCoding$kCMSampleAttachmentKey_IsDependedOnByOthers$kCMSampleAttachmentKey_NotSync$kCMSampleAttachmentKey_PartialSync$kCMSampleBufferAttachmentKey_CameraIntrinsicMatrix$kCMSampleBufferAttachmentKey_DisplayEmptyMediaImmediately$kCMSampleBufferAttachmentKey_DrainAfterDecoding$kCMSampleBufferAttachmentKey_DroppedFrameReason$kCMSampleBufferAttachmentKey_DroppedFrameReasonInfo$kCMSampleBufferAttachmentKey_EmptyMedia$kCMSampleBufferAttachmentKey_EndsPreviousSampleDuration$kCMSampleBufferAttachmentKey_FillDiscontinuitiesWithSilence$kCMSampleBufferAttachmentKey_ForceKeyFrame$kCMSampleBufferAttachmentKey_GradualDecoderRefresh$kCMSampleBufferAttachmentKey_PermanentEmptyMedia$kCMSampleBufferAttachmentKey_PostNotificationWhenConsumed$kCMSampleBufferAttachmentKey_ResetDecoderBeforeDecoding$kCMSampleBufferAttachmentKey_ResumeOutput$kCMSampleBufferAttachmentKey_Reverse$kCMSampleBufferAttachmentKey_SampleReferenceByteOffset$kCMSampleBufferAttachmentKey_SampleReferenceURL$kCMSampleBufferAttachmentKey_SpeedMultiplier$kCMSampleBufferAttachmentKey_StillImageLensStabilizationInfo$kCMSampleBufferAttachmentKey_TransitionID$kCMSampleBufferAttachmentKey_TrimDurationAtEnd$kCMSampleBufferAttachmentKey_TrimDurationAtStart$kCMSampleBufferConduitNotificationParameter_MaxUpcomingOutputPTS$kCMSampleBufferConduitNotificationParameter_MinUpcomingOutputPTS$kCMSampleBufferConduitNotificationParameter_ResumeTag$kCMSampleBufferConduitNotificationParameter_UpcomingOutputPTSRangeMayOverlapQueuedOutputPTSRange$kCMSampleBufferConduitNotification_InhibitOutputUntil$kCMSampleBufferConduitNotification_ResetOutput$kCMSampleBufferConduitNotification_UpcomingOutputPTSRangeChanged$kCMSampleBufferConsumerNotification_BufferConsumed$kCMSampleBufferDroppedFrameReasonInfo_CameraModeSwitch$kCMSampleBufferDroppedFrameReason_Discontinuity$kCMSampleBufferDroppedFrameReason_FrameWasLate$kCMSampleBufferDroppedFrameReason_OutOfBuffers$kCMSampleBufferLensStabilizationInfo_Active$kCMSampleBufferLensStabilizationInfo_Off$kCMSampleBufferLensStabilizationInfo_OutOfRange$kCMSampleBufferLensStabilizationInfo_Unavailable$kCMSampleBufferNotificationParameter_OSStatus$kCMSampleBufferNotification_DataBecameReady$kCMSampleBufferNotification_DataFailed$kCMSoundDescriptionFlavor_3GPFamily$kCMSoundDescriptionFlavor_ISOFamily$kCMSoundDescriptionFlavor_QuickTimeMovie$kCMSoundDescriptionFlavor_QuickTimeMovieV2$kCMTextFormatDescriptionColor_Alpha$kCMTextFormatDescriptionColor_Blue$kCMTextFormatDescriptionColor_Green$kCMTextFormatDescriptionColor_Red$kCMTextFormatDescriptionExtension_BackgroundColor$kCMTextFormatDescriptionExtension_DefaultFontName$kCMTextFormatDescriptionExtension_DefaultStyle$kCMTextFormatDescriptionExtension_DefaultTextBox$kCMTextFormatDescriptionExtension_DisplayFlags$kCMTextFormatDescriptionExtension_FontTable$kCMTextFormatDescriptionExtension_HorizontalJustification$kCMTextFormatDescriptionExtension_TextJustification$kCMTextFormatDescriptionExtension_VerticalJustification$kCMTextFormatDescriptionRect_Bottom$kCMTextFormatDescriptionRect_Left$kCMTextFormatDescriptionRect_Right$kCMTextFormatDescriptionRect_Top$kCMTextFormatDescriptionStyle_Ascent$kCMTextFormatDescriptionStyle_EndChar$kCMTextFormatDescriptionStyle_Font$kCMTextFormatDescriptionStyle_FontFace$kCMTextFormatDescriptionStyle_FontSize$kCMTextFormatDescriptionStyle_ForegroundColor$kCMTextFormatDescriptionStyle_Height$kCMTextFormatDescriptionStyle_StartChar$kCMTextMarkupAlignmentType_End$kCMTextMarkupAlignmentType_Left$kCMTextMarkupAlignmentType_Middle$kCMTextMarkupAlignmentType_Right$kCMTextMarkupAlignmentType_Start$kCMTextMarkupAttribute_Alignment$kCMTextMarkupAttribute_BackgroundColorARGB$kCMTextMarkupAttribute_BaseFontSizePercentageRelativeToVideoHeight$kCMTextMarkupAttribute_BoldStyle$kCMTextMarkupAttribute_CharacterBackgroundColorARGB$kCMTextMarkupAttribute_CharacterEdgeStyle$kCMTextMarkupAttribute_FontFamilyName$kCMTextMarkupAttribute_ForegroundColorARGB$kCMTextMarkupAttribute_GenericFontFamilyName$kCMTextMarkupAttribute_ItalicStyle$kCMTextMarkupAttribute_OrthogonalLinePositionPercentageRelativeToWritingDirection$kCMTextMarkupAttribute_RelativeFontSize$kCMTextMarkupAttribute_TextPositionPercentageRelativeToWritingDirection$kCMTextMarkupAttribute_UnderlineStyle$kCMTextMarkupAttribute_VerticalLayout$kCMTextMarkupAttribute_WritingDirectionSizePercentage$kCMTextMarkupCharacterEdgeStyle_Depressed$kCMTextMarkupCharacterEdgeStyle_DropShadow$kCMTextMarkupCharacterEdgeStyle_None$kCMTextMarkupCharacterEdgeStyle_Raised$kCMTextMarkupCharacterEdgeStyle_Uniform$kCMTextMarkupGenericFontName_Casual$kCMTextMarkupGenericFontName_Cursive$kCMTextMarkupGenericFontName_Default$kCMTextMarkupGenericFontName_Fantasy$kCMTextMarkupGenericFontName_Monospace$kCMTextMarkupGenericFontName_MonospaceSansSerif$kCMTextMarkupGenericFontName_MonospaceSerif$kCMTextMarkupGenericFontName_ProportionalSansSerif$kCMTextMarkupGenericFontName_ProportionalSerif$kCMTextMarkupGenericFontName_SansSerif$kCMTextMarkupGenericFontName_Serif$kCMTextMarkupGenericFontName_SmallCapital$kCMTextVerticalLayout_LeftToRight$kCMTextVerticalLayout_RightToLeft$kCMTimeCodeFormatDescriptionExtension_SourceReferenceName$kCMTimeCodeFormatDescriptionKey_LangCode$kCMTimeCodeFormatDescriptionKey_Value$kCMTimeEpochKey$kCMTimeFlagsKey$kCMTimeIndefinite@{_CMTime=qiIq}$kCMTimeInvalid@{_CMTime=qiIq}$kCMTimeMappingInvalid@{_CMTimeMapping={_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}}$kCMTimeMappingSourceKey$kCMTimeMappingTargetKey$kCMTimeNegativeInfinity@{_CMTime=qiIq}$kCMTimePositiveInfinity@{_CMTime=qiIq}$kCMTimeRangeDurationKey$kCMTimeRangeInvalid@{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}$kCMTimeRangeStartKey$kCMTimeRangeZero@{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}$kCMTimeScaleKey$kCMTimeValueKey$kCMTimeZero@{_CMTime=qiIq}$kCMTimebaseNotificationKey_EventTime$kCMTimebaseNotification_EffectiveRateChanged$kCMTimebaseNotification_TimeJumped$kCMTimingInfoInvalid@{_CMSampleTimingInfo={_CMTime=qiIq}{_CMTime=qiIq}{_CMTime=qiIq}}$'''
enums = '''$kCMAttachmentMode_ShouldNotPropagate@0$kCMAttachmentMode_ShouldPropagate@1$kCMAudioCodecType_AAC_AudibleProtected@1633771875$kCMAudioCodecType_AAC_LCProtected@1885430115$kCMAudioFormatDescriptionMask_All@15$kCMAudioFormatDescriptionMask_ChannelLayout@4$kCMAudioFormatDescriptionMask_Extensions@8$kCMAudioFormatDescriptionMask_MagicCookie@2$kCMAudioFormatDescriptionMask_StreamBasicDescription@1$kCMBlockBufferAlwaysCopyDataFlag@2$kCMBlockBufferAssureMemoryNowFlag@1$kCMBlockBufferBadCustomBlockSourceErr@-12702$kCMBlockBufferBadLengthParameterErr@-12704$kCMBlockBufferBadOffsetParameterErr@-12703$kCMBlockBufferBadPointerParameterErr@-12705$kCMBlockBufferBlockAllocationFailedErr@-12701$kCMBlockBufferCustomBlockSourceVersion@0$kCMBlockBufferDontOptimizeDepthFlag@4$kCMBlockBufferEmptyBBufErr@-12706$kCMBlockBufferInsufficientSpaceErr@-12708$kCMBlockBufferNoErr@0$kCMBlockBufferPermitEmptyReferenceFlag@8$kCMBlockBufferStructureAllocationFailedErr@-12700$kCMBlockBufferUnallocatedBlockErr@-12707$kCMBufferQueueError_AllocationFailed@-12760$kCMBufferQueueError_BadTriggerDuration@-12765$kCMBufferQueueError_CannotModifyQueueFromTriggerCallback@-12766$kCMBufferQueueError_EnqueueAfterEndOfData@-12763$kCMBufferQueueError_InvalidBuffer@-12769$kCMBufferQueueError_InvalidCMBufferCallbacksStruct@-12762$kCMBufferQueueError_InvalidTriggerCondition@-12767$kCMBufferQueueError_InvalidTriggerToken@-12768$kCMBufferQueueError_QueueIsFull@-12764$kCMBufferQueueError_RequiredParameterMissing@-12761$kCMBufferQueueTrigger_WhenBufferCountBecomesGreaterThan@11$kCMBufferQueueTrigger_WhenBufferCountBecomesLessThan@10$kCMBufferQueueTrigger_WhenDataBecomesReady@7$kCMBufferQueueTrigger_WhenDurationBecomesGreaterThan@3$kCMBufferQueueTrigger_WhenDurationBecomesGreaterThanOrEqualTo@4$kCMBufferQueueTrigger_WhenDurationBecomesGreaterThanOrEqualToAndBufferCountBecomesGreaterThan@12$kCMBufferQueueTrigger_WhenDurationBecomesLessThan@1$kCMBufferQueueTrigger_WhenDurationBecomesLessThanOrEqualTo@2$kCMBufferQueueTrigger_WhenEndOfDataReached@8$kCMBufferQueueTrigger_WhenMaxPresentationTimeStampChanges@6$kCMBufferQueueTrigger_WhenMinPresentationTimeStampChanges@5$kCMBufferQueueTrigger_WhenReset@9$kCMClockError_AllocationFailed@-12747$kCMClockError_InvalidParameter@-12746$kCMClockError_MissingRequiredParameter@-12745$kCMClockError_UnsupportedOperation@-12756$kCMClosedCaptionFormatType_ATSC@1635017571$kCMClosedCaptionFormatType_CEA608@1664495672$kCMClosedCaptionFormatType_CEA708@1664561208$kCMFormatDescriptionBridgeError_AllocationFailed@-12713$kCMFormatDescriptionBridgeError_IncompatibleFormatDescription@-12716$kCMFormatDescriptionBridgeError_InvalidFormatDescription@-12715$kCMFormatDescriptionBridgeError_InvalidParameter@-12712$kCMFormatDescriptionBridgeError_InvalidSerializedSampleDescription@-12714$kCMFormatDescriptionBridgeError_InvalidSlice@-12719$kCMFormatDescriptionBridgeError_UnsupportedSampleDescriptionFlavor@-12717$kCMFormatDescriptionError_AllocationFailed@-12711$kCMFormatDescriptionError_InvalidParameter@-12710$kCMFormatDescriptionError_ValueNotAvailable@-12718$kCMMPEG2VideoProfile_HDV_1080i50@1751414323$kCMMPEG2VideoProfile_HDV_1080i60@1751414322$kCMMPEG2VideoProfile_HDV_1080p24@1751414326$kCMMPEG2VideoProfile_HDV_1080p25@1751414327$kCMMPEG2VideoProfile_HDV_1080p30@1751414328$kCMMPEG2VideoProfile_HDV_720p24@1751414324$kCMMPEG2VideoProfile_HDV_720p25@1751414325$kCMMPEG2VideoProfile_HDV_720p30@1751414321$kCMMPEG2VideoProfile_HDV_720p50@1751414369$kCMMPEG2VideoProfile_HDV_720p60@1751414329$kCMMPEG2VideoProfile_XDCAM_EX_1080i50_VBR35@2019849827$kCMMPEG2VideoProfile_XDCAM_EX_1080i60_VBR35@2019849826$kCMMPEG2VideoProfile_XDCAM_EX_1080p24_VBR35@2019849828$kCMMPEG2VideoProfile_XDCAM_EX_1080p25_VBR35@2019849829$kCMMPEG2VideoProfile_XDCAM_EX_1080p30_VBR35@2019849830$kCMMPEG2VideoProfile_XDCAM_EX_720p24_VBR35@2019849780$kCMMPEG2VideoProfile_XDCAM_EX_720p25_VBR35@2019849781$kCMMPEG2VideoProfile_XDCAM_EX_720p30_VBR35@2019849777$kCMMPEG2VideoProfile_XDCAM_EX_720p50_VBR35@2019849825$kCMMPEG2VideoProfile_XDCAM_EX_720p60_VBR35@2019849785$kCMMPEG2VideoProfile_XDCAM_HD422_1080i50_CBR50@2019833187$kCMMPEG2VideoProfile_XDCAM_HD422_1080i60_CBR50@2019833186$kCMMPEG2VideoProfile_XDCAM_HD422_1080p24_CBR50@2019833188$kCMMPEG2VideoProfile_XDCAM_HD422_1080p25_CBR50@2019833189$kCMMPEG2VideoProfile_XDCAM_HD422_1080p30_CBR50@2019833190$kCMMPEG2VideoProfile_XDCAM_HD422_540p@2019846194$kCMMPEG2VideoProfile_XDCAM_HD422_720p24_CBR50@2019833140$kCMMPEG2VideoProfile_XDCAM_HD422_720p25_CBR50@2019833141$kCMMPEG2VideoProfile_XDCAM_HD422_720p30_CBR50@2019833137$kCMMPEG2VideoProfile_XDCAM_HD422_720p50_CBR50@2019833185$kCMMPEG2VideoProfile_XDCAM_HD422_720p60_CBR50@2019833145$kCMMPEG2VideoProfile_XDCAM_HD_1080i50_VBR35@2019849779$kCMMPEG2VideoProfile_XDCAM_HD_1080i60_VBR35@2019849778$kCMMPEG2VideoProfile_XDCAM_HD_1080p24_VBR35@2019849782$kCMMPEG2VideoProfile_XDCAM_HD_1080p25_VBR35@2019849783$kCMMPEG2VideoProfile_XDCAM_HD_1080p30_VBR35@2019849784$kCMMPEG2VideoProfile_XDCAM_HD_540p@2019846244$kCMMPEG2VideoProfile_XF@2019981873$kCMMediaType_Audio@1936684398$kCMMediaType_ClosedCaption@1668047728$kCMMediaType_Metadata@1835365473$kCMMediaType_Muxed@1836415096$kCMMediaType_Subtitle@1935832172$kCMMediaType_Text@1952807028$kCMMediaType_TimeCode@1953325924$kCMMediaType_Video@1986618469$kCMMemoryPoolError_AllocationFailed@-15490$kCMMemoryPoolError_InvalidParameter@-15491$kCMMetadataDataTypeRegistryError_AllocationFailed@-16310$kCMMetadataDataTypeRegistryError_BadDataTypeIdentifier@-16312$kCMMetadataDataTypeRegistryError_DataTypeAlreadyRegistered@-16313$kCMMetadataDataTypeRegistryError_MultipleConformingBaseTypes@-16315$kCMMetadataDataTypeRegistryError_RequiredParameterMissing@-16311$kCMMetadataDataTypeRegistryError_RequiresConformingBaseType@-16314$kCMMetadataFormatType_Boxed@1835360888$kCMMetadataFormatType_EMSG@1701671783$kCMMetadataFormatType_ICY@1768126752$kCMMetadataFormatType_ID3@1768174368$kCMMetadataIdentifierError_AllocationFailed@-16300$kCMMetadataIdentifierError_BadIdentifier@-16307$kCMMetadataIdentifierError_BadKey@-16302$kCMMetadataIdentifierError_BadKeyLength@-16303$kCMMetadataIdentifierError_BadKeySpace@-16306$kCMMetadataIdentifierError_BadKeyType@-16304$kCMMetadataIdentifierError_BadNumberKey@-16305$kCMMetadataIdentifierError_NoKeyValueAvailable@-16308$kCMMetadataIdentifierError_RequiredParameterMissing@-16301$kCMMuxedStreamType_DV@1685463072$kCMMuxedStreamType_MPEG1System@1836069235$kCMMuxedStreamType_MPEG2Program@1836069488$kCMMuxedStreamType_MPEG2Transport@1836069492$kCMPersistentTrackID_Invalid@0$kCMPixelFormat_16BE555@16$kCMPixelFormat_16BE565@1110783541$kCMPixelFormat_16LE555@1278555445$kCMPixelFormat_16LE5551@892679473$kCMPixelFormat_16LE565@1278555701$kCMPixelFormat_24RGB@24$kCMPixelFormat_32ARGB@32$kCMPixelFormat_32BGRA@1111970369$kCMPixelFormat_422YpCbCr10@1983000880$kCMPixelFormat_422YpCbCr16@1983000886$kCMPixelFormat_422YpCbCr8@846624121$kCMPixelFormat_422YpCbCr8_yuvs@2037741171$kCMPixelFormat_4444YpCbCrA8@1983131704$kCMPixelFormat_444YpCbCr10@1983131952$kCMPixelFormat_444YpCbCr8@1983066168$kCMPixelFormat_8IndexedGray_WhiteIsZero@40$kCMSampleBufferError_AllocationFailed@-12730$kCMSampleBufferError_AlreadyHasDataBuffer@-12732$kCMSampleBufferError_ArrayTooSmall@-12737$kCMSampleBufferError_BufferHasNoSampleSizes@-12735$kCMSampleBufferError_BufferHasNoSampleTimingInfo@-12736$kCMSampleBufferError_BufferNotReady@-12733$kCMSampleBufferError_CannotSubdivide@-12739$kCMSampleBufferError_DataCanceled@-16751$kCMSampleBufferError_DataFailed@-16750$kCMSampleBufferError_InvalidEntryCount@-12738$kCMSampleBufferError_InvalidMediaFormat@-12743$kCMSampleBufferError_InvalidMediaTypeForOperation@-12741$kCMSampleBufferError_InvalidSampleData@-12742$kCMSampleBufferError_Invalidated@-12744$kCMSampleBufferError_RequiredParameterMissing@-12731$kCMSampleBufferError_SampleIndexOutOfRange@-12734$kCMSampleBufferError_SampleTimingInfoInvalid@-12740$kCMSampleBufferFlag_AudioBufferList_Assure16ByteAlignment@1$kCMSimpleQueueError_AllocationFailed@-12770$kCMSimpleQueueError_ParameterOutOfRange@-12772$kCMSimpleQueueError_QueueIsFull@-12773$kCMSimpleQueueError_RequiredParameterMissing@-12771$kCMSubtitleFormatType_3GText@1954034535$kCMSubtitleFormatType_WebVTT@2004251764$kCMSyncError_AllocationFailed@-12754$kCMSyncError_InvalidParameter@-12753$kCMSyncError_MissingRequiredParameter@-12752$kCMSyncError_RateMustBeNonZero@-12755$kCMTextDisplayFlag_allSubtitlesForced@2147483648$kCMTextDisplayFlag_continuousKaraoke@2048$kCMTextDisplayFlag_fillTextRegion@262144$kCMTextDisplayFlag_forcedSubtitlesPresent@1073741824$kCMTextDisplayFlag_obeySubtitleFormatting@536870912$kCMTextDisplayFlag_scrollDirectionMask@384$kCMTextDisplayFlag_scrollDirection_bottomToTop@0$kCMTextDisplayFlag_scrollDirection_leftToRight@384$kCMTextDisplayFlag_scrollDirection_rightToLeft@128$kCMTextDisplayFlag_scrollDirection_topToBottom@256$kCMTextDisplayFlag_scrollIn@32$kCMTextDisplayFlag_scrollOut@64$kCMTextDisplayFlag_writeTextVertically@131072$kCMTextFormatType_3GText@1954034535$kCMTextFormatType_QTText@1952807028$kCMTextJustification_bottom_right@-1$kCMTextJustification_centered@1$kCMTextJustification_left_top@0$kCMTimeCodeFlag_24HourMax@2$kCMTimeCodeFlag_DropFrame@1$kCMTimeCodeFlag_NegTimesOK@4$kCMTimeCodeFormatType_Counter32@1668166450$kCMTimeCodeFormatType_Counter64@1668167220$kCMTimeCodeFormatType_TimeCode32@1953325924$kCMTimeCodeFormatType_TimeCode64@1952658996$kCMTimeFlags_HasBeenRounded@2$kCMTimeFlags_ImpliedValueFlagsMask@28$kCMTimeFlags_Indefinite@16$kCMTimeFlags_NegativeInfinity@8$kCMTimeFlags_PositiveInfinity@4$kCMTimeFlags_Valid@1$kCMTimeMaxTimescale@2147483647$kCMTimeRoundingMethod_Default@1$kCMTimeRoundingMethod_QuickTime@4$kCMTimeRoundingMethod_RoundAwayFromZero@3$kCMTimeRoundingMethod_RoundHalfAwayFromZero@1$kCMTimeRoundingMethod_RoundTowardNegativeInfinity@6$kCMTimeRoundingMethod_RoundTowardPositiveInfinity@5$kCMTimeRoundingMethod_RoundTowardZero@2$kCMTimebaseError_AllocationFailed@-12750$kCMTimebaseError_InvalidParameter@-12749$kCMTimebaseError_MissingRequiredParameter@-12748$kCMTimebaseError_ReadOnly@-12757$kCMTimebaseError_TimerIntervalTooShort@-12751$kCMTimebaseVeryLongCFTimeInterval@8073216000.0$kCMVideoCodecType_422YpCbCr8@846624121$kCMVideoCodecType_Animation@1919706400$kCMVideoCodecType_AppleProRes422@1634755438$kCMVideoCodecType_AppleProRes422HQ@1634755432$kCMVideoCodecType_AppleProRes422LT@1634755443$kCMVideoCodecType_AppleProRes422Proxy@1634755439$kCMVideoCodecType_AppleProRes4444@1634743400$kCMVideoCodecType_AppleProRes4444XQ@1634743416$kCMVideoCodecType_AppleProResRAW@1634759278$kCMVideoCodecType_AppleProResRAWHQ@1634759272$kCMVideoCodecType_Cinepak@1668704612$kCMVideoCodecType_DVCNTSC@1685480224$kCMVideoCodecType_DVCPAL@1685480304$kCMVideoCodecType_DVCPROHD1080i50@1685481525$kCMVideoCodecType_DVCPROHD1080i60@1685481526$kCMVideoCodecType_DVCPROHD1080p25@1685481522$kCMVideoCodecType_DVCPROHD1080p30@1685481523$kCMVideoCodecType_DVCPROHD720p50@1685481585$kCMVideoCodecType_DVCPROHD720p60@1685481584$kCMVideoCodecType_DVCPro50NTSC@1685468526$kCMVideoCodecType_DVCPro50PAL@1685468528$kCMVideoCodecType_DVCProPAL@1685483632$kCMVideoCodecType_H263@1748121139$kCMVideoCodecType_H264@1635148593$kCMVideoCodecType_HEVC@1752589105$kCMVideoCodecType_HEVCWithAlpha@1836415073$kCMVideoCodecType_JPEG@1785750887$kCMVideoCodecType_JPEG_OpenDML@1684890161$kCMVideoCodecType_MPEG1Video@1836069238$kCMVideoCodecType_MPEG2Video@1836069494$kCMVideoCodecType_MPEG4Video@1836070006$kCMVideoCodecType_SorensonVideo@1398165809$kCMVideoCodecType_SorensonVideo3@1398165811$kCMVideoCodecType_VP9@1987063865$'''
misc.update({})
functions={'CMBlockBufferCreateEmpty': (b'i^{__CFAllocator=}II^^{OpaqueCMBlockBuffer=}', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMTimebaseCreateWithMasterTimebase': (b'i^{__CFAllocator=}^{OpaqueCMTimebase=}^^{OpaqueCMTimebase=}', '', {'retval': {'already_cfretained': True}, 'arguments': {2: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMBufferQueueMarkEndOfData': (b'i^{opaqueCMBufferQueue=}',), 'CMFormatDescriptionCreate': (b'i^{__CFAllocator=}II^{__CFDictionary=}^^{opaqueCMFormatDescription=}', '', {'retval': {'already_cfretained': True}, 'arguments': {4: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMBufferQueueIsEmpty': (b'Z^{opaqueCMBufferQueue=}',), 'CMMetadataFormatDescriptionCreateFromBigEndianMetadataDescriptionBlockBuffer': (b'i^{__CFAllocator=}^{OpaqueCMBlockBuffer=}^{__CFString=}^^{opaqueCMFormatDescription=}', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMAudioFormatDescriptionGetStreamBasicDescription': (b'^{AudioStreamBasicDescription=dIIIIIIII}^{opaqueCMFormatDescription=}',), 'CMTimeMappingMakeFromDictionary': (b'{_CMTimeMapping={_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}}^{__CFDictionary=}',), 'CMBufferQueueEnqueue': (b'i^{opaqueCMBufferQueue=}@',), 'CMBufferQueueInstallTrigger': (b'i^{opaqueCMBufferQueue=}^?^vi{_CMTime=qiIq}^^{opaqueCMBufferQueueTriggerToken=}', '', {'arguments': {1: {'callable': {'retval': {'type': b'v'}, 'arguments': {0: {'type': b'^v'}, 1: {'type': b'^{opaqueCMBufferQueueTriggerToken=}'}}}}, 5: {'type_modifier': 'o'}}}), 'CMTimebaseGetMasterClock': (b'^{OpaqueCMClock=}^{OpaqueCMTimebase=}',), 'CMTextFormatDescriptionGetDefaultStyle': (b'i^{opaqueCMFormatDescription=}^S^Z^Z^Z^d^d', '', {'arguments': {1: {'type_modifier': 'o'}, 2: {'type_modifier': 'o'}, 3: {'type_modifier': 'o'}, 4: {'type_modifier': 'o'}, 5: {'type_modifier': 'o'}, 6: {'c_array_of_fixed_length': 4, 'type_modifier': 'o'}}}), 'CMSampleBufferGetSampleTimingInfo': (b'i^{opaqueCMSampleBuffer=}q^{_CMSampleTimingInfo={_CMTime=qiIq}{_CMTime=qiIq}{_CMTime=qiIq}}', '', {'arguments': {2: {'type_modifier': 'o'}}}), 'CMBufferQueueGetMaxPresentationTimeStamp': (b'{_CMTime=qiIq}^{opaqueCMBufferQueue=}',), 'CMTimebaseCopyMasterClock': (b'^{OpaqueCMClock=}^{OpaqueCMTimebase=}', '', {'retval': {'already_cfretained': True}}), 'CMClockMightDrift': (b'Z^{OpaqueCMClock=}^{OpaqueCMClock=}',), 'CMMetadataCreateIdentifierForKeyAndKeySpace': (b'i^{__CFAllocator=}@^{__CFString=}^^{__CFString=}', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMSetAttachments': (b'v@^{__CFDictionary=}I',), 'CMTimebaseGetTimeAndRate': (b'i^{OpaqueCMTimebase=}^{_CMTime=qiIq}^d',), 'CMMetadataDataTypeRegistryDataTypeConformsToDataType': (b'Z^{__CFString=}^{__CFString=}',), 'CMVideoFormatDescriptionGetDimensions': (b'{_CMVideoDimensions=ii}^{opaqueCMFormatDescription=}',), 'CMMemoryPoolInvalidate': (b'v^{OpaqueCMMemoryPool=}',), 'CMBufferQueueRemoveTrigger': (b'i^{opaqueCMBufferQueue=}^{opaqueCMBufferQueueTriggerToken=}',), 'CMSampleBufferCreate': (b'i^{__CFAllocator=}^{OpaqueCMBlockBuffer=}Z^?^v^{opaqueCMFormatDescription=}qq^{_CMSampleTimingInfo={_CMTime=qiIq}{_CMTime=qiIq}{_CMTime=qiIq}}q^Q^^{opaqueCMSampleBuffer=}', '', {'retval': {'already_cfretained': True}, 'arguments': {8: {'c_array_length_in_arg': 7, 'type_modifier': 'n'}, 11: {'already_cfretained': True, 'type_modifier': 'o'}, 10: {'c_array_length_in_arg': 9, 'type_modifier': 'n'}, 3: {'callable': {'retval': {'type': b'i'}, 'arguments': {0: {'type': b'^{opaqueCMSampleBuffer=}'}, 1: {'type': b'^v'}}}}}}), 'CMTimeCodeFormatDescriptionGetFrameQuanta': (b'I^{opaqueCMFormatDescription=}',), 'CMTimeCodeFormatDescriptionCopyAsBigEndianTimeCodeDescriptionBlockBuffer': (b'i^{__CFAllocator=}^{opaqueCMFormatDescription=}^{__CFString=}^^{OpaqueCMBlockBuffer=}', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMSampleBufferSetDataBufferFromAudioBufferList': (b'i^{opaqueCMSampleBuffer=}^{__CFAllocator=}^{__CFAllocator=}I^{AudioBufferList=I[1{AudioBuffer=II^v}]}',), 'CMSwapBigEndianTextDescriptionToHost': (b'i^CQ', '', {'arguments': {0: {'c_array_length_in_arg': 1, 'type_modifier': 'N'}}}), 'CMBufferQueueGetTotalSize': (b'Q^{opaqueCMBufferQueue=}',), 'CMTimebaseGetTimeWithTimeScale': (b'{_CMTime=qiIq}^{OpaqueCMTimebase=}iI',), 'CMTimebaseCreateWithMasterClock': (b'i^{__CFAllocator=}^{OpaqueCMClock=}^^{OpaqueCMTimebase=}', '', {'retval': {'already_cfretained': True}, 'arguments': {2: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMSwapHostEndianTextDescriptionToBig': (b'i^CQ', '', {'arguments': {0: {'c_array_length_in_arg': 1, 'type_modifier': 'N'}}}), 'CMSyncGetRelativeRateAndAnchorTime': (b'i@@^d^{_CMTime=qiIq}^{_CMTime=qiIq}', '', {'arguments': {2: {'type_modifier': 'o'}, 3: {'type_modifier': 'o'}, 4: {'type_modifier': 'o'}}}), 'CMTimeRangeFromTimeToTime': (b'{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}{_CMTime=qiIq}{_CMTime=qiIq}',), 'CMClockMakeHostTimeFromSystemUnits': (b'{_CMTime=qiIq}Q',), 'CMSwapHostEndianTimeCodeDescriptionToBig': (b'i^CQ', '', {'arguments': {0: {'c_array_length_in_arg': 1, 'type_modifier': 'N'}}}), 'CMAudioFormatDescriptionEqual': (b'Z^{opaqueCMFormatDescription=}^{opaqueCMFormatDescription=}I^I', '', {'arguments': {3: {'type_modifier': 'o'}}}), 'CMAudioSampleBufferCreateWithPacketDescriptionsAndMakeDataReadyHandler': (b'i^{__CFAllocator=}^{OpaqueCMBlockBuffer=}Z^{opaqueCMFormatDescription=}q{_CMTime=qiIq}^{AudioStreamPacketDescription=qII}^^{opaqueCMSampleBuffer=}@?', '', {'retval': {'already_cfretained': True}, 'arguments': {8: {'callable': {'retval': {'type': b'i'}, 'arguments': {0: {'type': '^v'}, 1: {'type': '^{OpaqueCMSampleBuffer=}'}}}}, 6: {'c_array_length_in_arg': 5, 'type_modifier': 'n'}, 7: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMSampleBufferMakeDataReady': (b'i^{opaqueCMSampleBuffer=}',), 'CMClosedCaptionFormatDescriptionCreateFromBigEndianClosedCaptionDescriptionData': (b'i^{__CFAllocator=}^CQ^{__CFString=}^^{opaqueCMFormatDescription=}', '', {'retval': {'already_cfretained': True}, 'arguments': {1: {'c_array_length_in_arg': 2, 'type_modifier': 'n'}, 4: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMTimeSubtract': (b'{_CMTime=qiIq}{_CMTime=qiIq}{_CMTime=qiIq}',), 'CMSampleBufferGetSampleTimingInfoArray': (b'i^{opaqueCMSampleBuffer=}q^{_CMSampleTimingInfo={_CMTime=qiIq}{_CMTime=qiIq}{_CMTime=qiIq}}^q', '', {'arguments': {2: {'c_array_length_in_arg': 1, 'type_modifier': 'o'}, 3: {'type_modifier': 'o'}}}), 'CMSampleBufferGetSampleAttachmentsArray': (b'^{__CFArray=}^{opaqueCMSampleBuffer=}Z',), 'CMTimeAbsoluteValue': (b'{_CMTime=qiIq}{_CMTime=qiIq}',), 'CMBufferQueueTestTrigger': (b'Z^{opaqueCMBufferQueue=}^{opaqueCMBufferQueueTriggerToken=}',), 'CMFormatDescriptionGetMediaType': (b'I^{opaqueCMFormatDescription=}',), 'CMTimebaseCopyMaster': (b'@^{OpaqueCMTimebase=}', '', {'retval': {'already_cfretained': True}}), 'CMSimpleQueueCreate': (b'i^{__CFAllocator=}i^^{opaqueCMSimpleQueue=}', '', {'retval': {'already_cfretained': True}, 'arguments': {2: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMMetadataFormatDescriptionGetKeyWithLocalID': (b'^{__CFDictionary=}^{opaqueCMFormatDescription=}I',), 'CMMetadataDataTypeRegistryRegisterDataType': (b'i^{__CFString=}^{__CFString=}^{__CFArray=}',), 'CMBufferQueueGetTypeID': (b'Q',), 'CMBlockBufferGetDataPointer': (b'i^{OpaqueCMBlockBuffer=}Q^Q^Q^^c',), 'CMSampleBufferGetImageBuffer': (b'^{__CVBuffer=}^{opaqueCMSampleBuffer=}',), 'CMBufferQueueCallForEachBuffer': (b'i^{opaqueCMBufferQueue=}^?^v', '', {'arguments': {1: {'callable': {'retval': {'type': b'i'}, 'arguments': {0: {'type': b'@'}, 1: {'type': b'^v'}}}}}}), 'CMMuxedFormatDescriptionCreate': (b'i^{__CFAllocator=}I^{__CFDictionary=}^^{opaqueCMFormatDescription=}', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMSampleBufferCreateForImageBufferWithMakeDataReadyHandler': (b'i^{__CFAllocator=}^{__CVBuffer=}Z^{opaqueCMFormatDescription=}^{_CMSampleTimingInfo={_CMTime=qiIq}{_CMTime=qiIq}{_CMTime=qiIq}}^^{opaqueCMSampleBuffer=}@?', '', {'retval': {'already_cfretained': True}, 'arguments': {5: {'already_cfretained': True, 'type_modifier': 'o'}, 6: {'callable': {'retval': {'type': b'i'}, 'arguments': {0: {'type': '^v'}, 1: {'type': '^{OpaqueCMSampleBuffer=}'}}}}}}), 'CMSwapHostEndianSoundDescriptionToBig': (b'i^CQ', '', {'arguments': {0: {'c_array_length_in_arg': 1, 'type_modifier': 'N'}}}), 'CMSwapBigEndianSoundDescriptionToHost': (b'i^CQ', '', {'arguments': {0: {'c_array_length_in_arg': 1, 'type_modifier': 'N'}}}), 'CMTimebaseGetMaster': (b'@^{OpaqueCMTimebase=}',), 'CMSampleBufferTrackDataReadiness': (b'i^{opaqueCMSampleBuffer=}^{opaqueCMSampleBuffer=}',), 'CMClockConvertHostTimeToSystemUnits': (b'Q{_CMTime=qiIq}',), 'CMBlockBufferFillDataBytes': (b'ic^{OpaqueCMBlockBuffer=}QQ',), 'CMBufferQueueGetBufferCount': (b'q^{opaqueCMBufferQueue=}',), 'CMTimeMappingMake': (b'{_CMTimeMapping={_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}',), 'CMSampleBufferCopyPCMDataIntoAudioBufferList': (b'i^{opaqueCMSampleBuffer=}ii^{AudioBufferList=I[1{AudioBuffer=II^v}]}', '', {'retval': {'already_cfretained': True}}), 'CMTimeMultiplyByRatio': (b'{_CMTime=qiIq}{_CMTime=qiIq}ii',), 'CMTextFormatDescriptionGetFontName': (b'i^{opaqueCMFormatDescription=}S^^{__CFString=}', '', {'arguments': {2: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMTimeRangeCopyDescription': (b'^{__CFString=}^{__CFAllocator=}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}', '', {'retval': {'already_cfretained': True}}), 'CMBufferQueueGetFirstPresentationTimeStamp': (b'{_CMTime=qiIq}^{opaqueCMBufferQueue=}',), 'CMSimpleQueueGetHead': (b'@^{opaqueCMSimpleQueue=}',), 'CMMetadataDataTypeRegistryDataTypeIsBaseDataType': (b'Z^{__CFString=}',), 'CMMetadataFormatDescriptionCreateWithKeys': (b'i^{__CFAllocator=}I^{__CFArray=}^^{opaqueCMFormatDescription=}', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMAudioDeviceClockSetAudioDeviceUID': (b'i^{OpaqueCMClock=}^{__CFString=}',), 'CMSwapHostEndianMetadataDescriptionToBig': (b'i^CQ', '', {'arguments': {0: {'c_array_length_in_arg': 1, 'type_modifier': 'N'}}}), 'CMBlockBufferGetDataLength': (b'Q^{OpaqueCMBlockBuffer=}',), 'CMSampleBufferGetNumSamples': (b'q^{opaqueCMSampleBuffer=}',), 'CMSwapBigEndianClosedCaptionDescriptionToHost': (b'i^CQ', '', {'arguments': {0: {'c_array_length_in_arg': 1, 'type_modifier': 'N'}}}), 'CMSampleBufferCopySampleBufferForRange': (b'i^{__CFAllocator=}^{opaqueCMSampleBuffer=}{_CFRange=qq}^^{opaqueCMSampleBuffer=}', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMGetAttachment': (b'@@^{__CFString=}^I', '', {'arguments': {2: {'type_modifier': 'o'}}}), 'CMSampleBufferGetDecodeTimeStamp': (b'{_CMTime=qiIq}^{opaqueCMSampleBuffer=}',), 'CMTimeCodeFormatDescriptionCreateFromBigEndianTimeCodeDescriptionBlockBuffer': (b'i^{__CFAllocator=}^{OpaqueCMBlockBuffer=}^{__CFString=}^^{opaqueCMFormatDescription=}', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMAudioFormatDescriptionCopyAsBigEndianSoundDescriptionBlockBuffer': (b'i^{__CFAllocator=}^{opaqueCMFormatDescription=}^{__CFString=}^^{OpaqueCMBlockBuffer=}', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMTextFormatDescriptionCreateFromBigEndianTextDescriptionBlockBuffer': (b'i^{__CFAllocator=}^{OpaqueCMBlockBuffer=}^{__CFString=}I^^{opaqueCMFormatDescription=}', '', {'retval': {'already_cfretained': True}, 'arguments': {4: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMBufferQueueGetFirstDecodeTimeStamp': (b'{_CMTime=qiIq}^{opaqueCMBufferQueue=}',), 'CMSampleBufferCallForEachSample': (b'i^{opaqueCMSampleBuffer=}^?^v', '', {'arguments': {1: {'callable': {'retval': {'type': b'i'}, 'arguments': {0: {'type': b'^{opaqueCMSampleBuffer=}'}, 1: {'type': b'q'}, 2: {'type': b'^v'}}}, 'callable_retained': False}}}), 'CMSwapHostEndianClosedCaptionDescriptionToBig': (b'i^CQ', '', {'arguments': {0: {'c_array_length_in_arg': 1, 'type_modifier': 'N'}}}), 'CMSampleBufferGetDuration': (b'{_CMTime=qiIq}^{opaqueCMSampleBuffer=}',), 'CMMetadataFormatDescriptionCreateWithMetadataSpecifications': (b'i^{__CFAllocator=}I^{__CFArray=}^^{opaqueCMFormatDescription=}', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMSwapHostEndianImageDescriptionToBig': (b'i^CQ', '', {'arguments': {0: {'c_array_length_in_arg': 1, 'type_modifier': 'N'}}}), 'CMSimpleQueueGetCapacity': (b'i^{opaqueCMSimpleQueue=}',), 'CMBufferQueueContainsEndOfData': (b'Z^{opaqueCMBufferQueue=}',), 'CMTimeRangeMake': (b'{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}{_CMTime=qiIq}{_CMTime=qiIq}',), 'CMTimeMappingShow': (b'v{_CMTimeMapping={_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}}',), 'CMMemoryPoolGetTypeID': (b'Q',), 'CMVideoFormatDescriptionCreateFromBigEndianImageDescriptionData': (b'i^{__CFAllocator=}^CQI^{__CFString=}^^{opaqueCMFormatDescription=}', '', {'retval': {'already_cfretained': True}, 'arguments': {1: {'c_array_length_in_arg': 2, 'type_modifier': 'n'}, 5: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMTimebaseGetMasterTimebase': (b'^{OpaqueCMTimebase=}^{OpaqueCMTimebase=}',), 'CMTimeMakeWithSeconds': (b'{_CMTime=qiIq}di',), 'CMVideoFormatDescriptionGetExtensionKeysCommonWithImageBuffers': (b'^{__CFArray=}',), 'CMClockGetTypeID': (b'Q',), 'CMTextFormatDescriptionGetJustification': (b'i^{opaqueCMFormatDescription=}^c^c', '', {'arguments': {1: {'type_modifier': 'o'}, 2: {'type_modifier': 'o'}}}), 'CMSampleBufferHasDataFailed': (b'Z^{opaqueCMSampleBuffer=}^i', '', {'arguments': {1: {'type_modifier': 'o'}}}), 'CMTimeMappingCopyAsDictionary': (b'^{__CFDictionary=}{_CMTimeMapping={_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}}^{__CFAllocator=}', '', {'retval': {'already_cfretained': True}}), 'CMFormatDescriptionGetMediaSubType': (b'I^{opaqueCMFormatDescription=}',), 'CMSwapBigEndianMetadataDescriptionToHost': (b'i^CQ', '', {'arguments': {0: {'c_array_length_in_arg': 1, 'type_modifier': 'N'}}}), 'CMBlockBufferAppendMemoryBlock': (b'i^{OpaqueCMBlockBuffer=}^vQ^{__CFAllocator=}^{_CMBlockBufferCustomBlockSource=I^?^?^v}QQI', '', {'arguments': {1: {'c_array_length_in_arg': 2, 'type_modifier': 'n'}, 4: {'type_modifier': 'n'}}}), 'CMTimebaseRemoveTimer': (b'i^{OpaqueCMTimebase=}^{__CFRunLoopTimer=}',), 'CMSimpleQueueEnqueue': (b'i^{opaqueCMSimpleQueue=}@',), 'CMTimeFoldIntoRange': (b'{_CMTime=qiIq}{_CMTime=qiIq}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}',), 'CMFormatDescriptionGetExtension': (b'@^{opaqueCMFormatDescription=}^{__CFString=}',), 'CMAudioFormatDescriptionGetRichestDecodableFormat': (b'^{AudioFormatListItem={AudioStreamBasicDescription=dIIIIIIII}I}^{opaqueCMFormatDescription=}',), 'CMSyncGetRelativeRate': (b'd@@',), 'CMMetadataCreateKeySpaceFromIdentifier': (b'i^{__CFAllocator=}^{__CFString=}^^{__CFString=}', '', {'retval': {'already_cfretained': True}, 'arguments': {2: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMTimebaseCopyUltimateMasterClock': (b'^{OpaqueCMClock=}^{OpaqueCMTimebase=}', '', {'retval': {'already_cfretained': True}}), 'CMBufferQueueGetCallbacksForUnsortedSampleBuffers': (b'^{_CMBufferCallbacks=I^v^?^?^?^?^?^{__CFString=}^?}',), 'CMSampleBufferGetDataBuffer': (b'^{OpaqueCMBlockBuffer=}^{opaqueCMSampleBuffer=}',), 'CMSampleBufferInvalidate': (b'i^{opaqueCMSampleBuffer=}',), 'CMBufferQueueGetDuration': (b'{_CMTime=qiIq}^{opaqueCMBufferQueue=}',), 'CMMetadataFormatDescriptionCopyAsBigEndianMetadataDescriptionBlockBuffer': (b'i^{__CFAllocator=}^{opaqueCMFormatDescription=}^{__CFString=}^^{OpaqueCMBlockBuffer=}', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMSetAttachment': (b'v@^{__CFString=}@I',), 'CMBufferQueueDequeueAndRetain': (b'@^{opaqueCMBufferQueue=}', '', {'retval': {'already_cfretained': True}}), 'CMTimebaseGetUltimateMasterClock': (b'^{OpaqueCMClock=}^{OpaqueCMTimebase=}',), 'CMTimeCopyDescription': (b'^{__CFString=}^{__CFAllocator=}{_CMTime=qiIq}', '', {'retval': {'already_cfretained': True}}), 'CMTimebaseRemoveTimerDispatchSource': (b'i^{OpaqueCMTimebase=}@',), 'CMCopyDictionaryOfAttachments': (b'^{__CFDictionary=}^{__CFAllocator=}@I', '', {'retval': {'already_cfretained': True}}), 'CMBufferQueueSetValidationCallback': (b'i^{opaqueCMBufferQueue=}^?^v', '', {'arguments': {1: {'callable': {'retval': {'type': b'i'}, 'arguments': {0: {'type': b'^{opaqueCMBufferQueue=}'}, 1: {'type': b'@'}, 2: {'type': b'^v'}}}}}}), 'CMTimeGetSeconds': (b'd{_CMTime=qiIq}',), 'CMSampleBufferGetSampleSize': (b'Q^{opaqueCMSampleBuffer=}q',), 'CMBufferQueueGetEndPresentationTimeStamp': (b'{_CMTime=qiIq}^{opaqueCMBufferQueue=}',), 'CMSampleBufferGetTypeID': (b'Q',), 'CMAudioDeviceClockGetAudioDevice': (b'i^{OpaqueCMClock=}^^{__CFString=}^I^Z', '', {'arguments': {1: {'type_modifier': 'o'}, 2: {'type_modifier': 'o'}, 3: {'type_modifier': 'o'}}}), 'CMAudioDeviceClockSetAudioDeviceID': (b'i^{OpaqueCMClock=}I',), 'CMTimeCodeFormatDescriptionGetFrameDuration': (b'{_CMTime=qiIq}^{opaqueCMFormatDescription=}',), 'CMTimebaseGetTime': (b'{_CMTime=qiIq}^{OpaqueCMTimebase=}',), 'CMSimpleQueueDequeue': (b'@^{opaqueCMSimpleQueue=}',), 'CMTimeRangeMakeFromDictionary': (b'{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}^{__CFDictionary=}',), 'CMTimebaseGetEffectiveRate': (b'd^{OpaqueCMTimebase=}',), 'CMVideoFormatDescriptionMatchesImageBuffer': (b'Z^{opaqueCMFormatDescription=}^{__CVBuffer=}',), 'CMSampleBufferCreateReadyWithImageBuffer': (b'i^{__CFAllocator=}^{__CVBuffer=}^{opaqueCMFormatDescription=}^{_CMSampleTimingInfo={_CMTime=qiIq}{_CMTime=qiIq}{_CMTime=qiIq}}^^{opaqueCMSampleBuffer=}', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'type_modifier': 'n'}, 4: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMTimeMultiply': (b'{_CMTime=qiIq}{_CMTime=qiIq}i',), 'CMSampleBufferCreateCopy': (b'i^{__CFAllocator=}^{opaqueCMSampleBuffer=}^^{opaqueCMSampleBuffer=}', '', {'retval': {'already_cfretained': True}, 'arguments': {2: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMMemoryPoolCreate': (b'^{OpaqueCMMemoryPool=}^{__CFDictionary=}', '', {'retval': {'already_cfretained': True}}), 'CMSampleBufferGetAudioStreamPacketDescriptions': (b'i^{opaqueCMSampleBuffer=}Q^{AudioStreamPacketDescription=qII}^Q', '', {'arguments': {2: {'c_array_length_in_arg': 1, 'type_modifier': 'o'}, 3: {'type_modifier': 'o'}}}), 'CMMetadataCreateKeyFromIdentifier': (b'i^{__CFAllocator=}^{__CFString=}^@', '', {'retval': {'already_cfretained': True}, 'arguments': {2: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMBufferQueueInstallTriggerWithIntegerThreshold': (b'i^{opaqueCMBufferQueue=}^?^viq^^{opaqueCMBufferQueueTriggerToken=}', '', {'arguments': {1: {'callable': {'retval': {'type': b'v'}, 'arguments': {0: {'type': b'^v'}, 1: {'type': b'^{opaqueCMBufferQueueTriggerToken=}'}}}}, 5: {'type_modifier': 'o'}}}), 'CMAudioClockCreate': (b'i^{__CFAllocator=}^^{OpaqueCMClock=}', '', {'retval': {'already_cfretained': True}}), 'CMMetadataFormatDescriptionCreateWithMetadataFormatDescriptionAndMetadataSpecifications': (b'i^{__CFAllocator=}^{opaqueCMFormatDescription=}^{__CFArray=}^^{opaqueCMFormatDescription=}', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMMemoryPoolGetAllocator': (b'^{__CFAllocator=}^{OpaqueCMMemoryPool=}',), 'CMSampleBufferCallBlockForEachSample': (b'i^{opaqueCMSampleBuffer=}@?', '', {'arguments': {1: {'callable': {'retval': {'type': b'v'}, 'arguments': {0: {'type': '^v'}, 1: {'type': '^{opaqueCMSampleBuffer=}'}, 2: {'type': 'q'}}}, 'block': {'retval': {'type': b'i'}, 'arguments': {0: {'type': b'^{opaqueCMSampleBuffer=}'}, 1: {'type': b'q'}}}}}}), 'CMTimeRangeShow': (b'v{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}',), 'CMBlockBufferCreateContiguous': (b'i^{__CFAllocator=}^{OpaqueCMBlockBuffer=}^{__CFAllocator=}^{_CMBlockBufferCustomBlockSource=I^?^?^v}QQI^^{OpaqueCMBlockBuffer=}', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'type_modifier': 'n'}, 7: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMBufferQueueDequeueIfDataReadyAndRetain': (b'@^{opaqueCMBufferQueue=}', '', {'retval': {'already_cfretained': True}}), 'CMBlockBufferGetTypeID': (b'Q',), 'CMTimeCodeFormatDescriptionCreateFromBigEndianTimeCodeDescriptionData': (b'i^{__CFAllocator=}^CQ^{__CFString=}^^{opaqueCMFormatDescription=}', '', {'retval': {'already_cfretained': True}, 'arguments': {1: {'c_array_length_in_arg': 2, 'type_modifier': 'n'}, 4: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMBlockBufferReplaceDataBytes': (b'i^v^{OpaqueCMBlockBuffer=}QQ', '', {'arguments': {0: {'c_array_length_in_arg': 3, 'type_modifier': 'n'}}}), 'CMDoesBigEndianSoundDescriptionRequireLegacyCBRSampleTableLayout': (b'Z^{OpaqueCMBlockBuffer=}^{__CFString=}',), 'CMBufferQueueGetMinPresentationTimeStamp': (b'{_CMTime=qiIq}^{opaqueCMBufferQueue=}',), 'CMTimebaseSetRateAndAnchorTime': (b'i^{OpaqueCMTimebase=}d{_CMTime=qiIq}{_CMTime=qiIq}',), 'CMTimebaseSetRate': (b'i^{OpaqueCMTimebase=}d',), 'CMMetadataDataTypeRegistryGetBaseDataTypeForConformingDataType': (b'^{__CFString=}^{__CFString=}',), 'CMSimpleQueueGetCount': (b'i^{opaqueCMSimpleQueue=}',), 'CMSampleBufferSetDataBuffer': (b'i^{opaqueCMSampleBuffer=}^{OpaqueCMBlockBuffer=}',), 'CMBlockBufferIsEmpty': (b'Z^{OpaqueCMBlockBuffer=}',), 'CMSyncConvertTime': (b'{_CMTime=qiIq}{_CMTime=qiIq}@@',), 'CMSyncMightDrift': (b'Z@@',), 'CMTextFormatDescriptionCreateFromBigEndianTextDescriptionData': (b'i^{__CFAllocator=}^CQ^{__CFString=}I^^{opaqueCMFormatDescription=}', '', {'retval': {'already_cfretained': True}, 'arguments': {1: {'c_array_length_in_arg': 2, 'type_modifier': 'n'}, 5: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMTimeCompare': (b'i{_CMTime=qiIq}{_CMTime=qiIq}',), 'CMAudioFormatDescriptionGetMagicCookie': (b'^v^{opaqueCMFormatDescription=}^Q', '', {'retval': {'c_array_length_in_arg': 1}, 'arguments': {1: {'type_modifier': 'o'}}}), 'CMSwapBigEndianImageDescriptionToHost': (b'i^CQ', '', {'arguments': {0: {'c_array_length_in_arg': 1, 'type_modifier': 'N'}}}), 'CMSampleBufferSetDataReady': (b'i^{opaqueCMSampleBuffer=}',), 'CMMetadataDataTypeRegistryGetDataTypeDescription': (b'^{__CFString=}^{__CFString=}',), 'CMFormatDescriptionGetExtensions': (b'^{__CFDictionary=}^{opaqueCMFormatDescription=}',), 'CMMetadataFormatDescriptionCreateFromBigEndianMetadataDescriptionData': (b'i^{__CFAllocator=}^CQ^{__CFString=}^^{opaqueCMFormatDescription=}', '', {'retval': {'already_cfretained': True}, 'arguments': {1: {'c_array_length_in_arg': 2, 'type_modifier': 'n'}, 4: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMSampleBufferDataIsReady': (b'Z^{opaqueCMSampleBuffer=}',), 'CMBlockBufferCreateWithMemoryBlock': (b'i^{__CFAllocator=}^vQ^{__CFAllocator=}^{_CMBlockBufferCustomBlockSource=I^?^?^v}QQI^^{OpaqueCMBlockBuffer=}', '', {'retval': {'already_cfretained': True}, 'arguments': {8: {'already_cfretained': True, 'type_modifier': 'o'}, 1: {'c_array_length_in_arg': 2, 'type_modifier': 'n'}, 4: {'type_modifier': 'n'}}}), 'CMBufferQueueGetHead': (b'@^{opaqueCMBufferQueue=}',), 'CMBlockBufferAppendBufferReference': (b'i^{OpaqueCMBlockBuffer=}^{OpaqueCMBlockBuffer=}QQI',), 'CMTimeMakeFromDictionary': (b'{_CMTime=qiIq}^{__CFDictionary=}',), 'CMSampleBufferSetInvalidateHandler': (b'i^{opaqueCMSampleBuffer=}@?', '', {'arguments': {1: {'callable': {'retval': {'type': b'v'}, 'arguments': {0: {'type': '^v'}, 1: {'type': '^{opaqueCMSampleBuffer=}'}}}}}}), 'CMTimebaseSetTimerNextFireTime': (b'i^{OpaqueCMTimebase=}^{__CFRunLoopTimer=}{_CMTime=qiIq}I',), 'CMTimeMappingMakeEmpty': (b'{_CMTimeMapping={_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}',), 'CMSampleBufferGetAudioBufferListWithRetainedBlockBuffer': (b'i^{opaqueCMSampleBuffer=}^Q^{AudioBufferList=I[1{AudioBuffer=II^v}]}Q^{__CFAllocator=}^{__CFAllocator=}I^^{OpaqueCMBlockBuffer=}', '', {'arguments': {1: {'type_modifier': 'o'}, 7: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMTimeConvertScale': (b'{_CMTime=qiIq}{_CMTime=qiIq}iI',), 'CMMetadataDataTypeRegistryGetBaseDataTypes': (b'^{__CFArray=}',), 'CMFormatDescriptionGetTypeID': (b'Q',), 'CMVideoFormatDescriptionCreateFromBigEndianImageDescriptionBlockBuffer': (b'i^{__CFAllocator=}^{OpaqueCMBlockBuffer=}I^{__CFString=}^^{opaqueCMFormatDescription=}', '', {'retval': {'already_cfretained': True}, 'arguments': {4: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMBufferQueueInstallTriggerHandler': (b'i@I{_CMTime=qiIq}^{opaqueCMBufferQueueTriggerToken=}@?', '', {'arguments': {3: {'type_modifier': 'o'}, 4: {'callable': {'retval': {'type': b'v'}, 'arguments': {0: {'type': '^v'}, 1: {'type': '^{opaqueCMBufferQueueTriggerToken=}'}}}}}}), 'CMClockGetAnchorTime': (b'i^{OpaqueCMClock=}^{_CMTime=qiIq}^{_CMTime=qiIq}', '', {'arguments': {1: {'type_modifier': 'o'}, 2: {'type_modifier': 'o'}}}), 'CMBlockBufferCopyDataBytes': (b'i^{OpaqueCMBlockBuffer=}QQ^v', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'c_array_length_in_arg': 2, 'type_modifier': 'o'}}}), 'CMSampleBufferSetOutputPresentationTimeStamp': (b'i^{opaqueCMSampleBuffer=}{_CMTime=qiIq}',), 'CMBlockBufferIsRangeContiguous': (b'Z^{OpaqueCMBlockBuffer=}QQ',), 'CMMetadataCreateKeyFromIdentifierAsCFData': (b'i^{__CFAllocator=}^{__CFString=}^^{__CFData=}', '', {'retval': {'already_cfretained': True}, 'arguments': {2: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMAudioDeviceClockCreateFromAudioDeviceID': (b'i^{__CFAllocator=}I^^{OpaqueCMClock=}', '', {'retval': {'already_cfretained': True}, 'arguments': {2: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMBufferQueueInstallTriggerHandlerWithIntegerThreshold': (b'i@Iq^{opaqueCMBufferQueueTriggerToken=}@?', '', {'arguments': {3: {'type_modifier': 'o'}, 4: {'callable': {'retval': {'type': b'v'}, 'arguments': {0: {'type': '^v'}, 1: {'type': '^{opaqueCMBufferQueueTriggerToken=}'}}}}}}), 'CMTimeRangeEqual': (b'Z{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}',), 'CMTimeRangeGetIntersection': (b'{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}',), 'CMClockGetHostTimeClock': (b'^{OpaqueCMClock=}',), 'CMTimeMapTimeFromRangeToRange': (b'{_CMTime=qiIq}{_CMTime=qiIq}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}',), 'CMBufferQueueReset': (b'i^{opaqueCMBufferQueue=}',), 'CMTimeMapDurationFromRangeToRange': (b'{_CMTime=qiIq}{_CMTime=qiIq}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}',), 'CMTextFormatDescriptionGetDefaultTextBox': (b'i^{opaqueCMFormatDescription=}Zd^{CGRect={CGPoint=dd}{CGSize=dd}}', '', {'arguments': {3: {'type_modifier': 'o'}}}), 'CMTimeRangeGetEnd': (b'{_CMTime=qiIq}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}',), 'CMBufferQueueSetValidationHandler': (b'i@@?', '', {'arguments': {1: {'callable': {'retval': {'type': b'v'}, 'arguments': {0: {'type': '^v'}, 1: {'type': '@'}, 2: {'type': '@'}}}}}}), 'CMTimeAdd': (b'{_CMTime=qiIq}{_CMTime=qiIq}{_CMTime=qiIq}',), 'CMTimeRangeContainsTimeRange': (b'Z{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}',), 'CMSampleBufferSetDataFailed': (b'i^{opaqueCMSampleBuffer=}i',), 'CMTimebaseSetTimerDispatchSourceToFireImmediately': (b'i^{OpaqueCMTimebase=}@',), 'CMAudioFormatDescriptionGetMostCompatibleFormat': (b'^{AudioFormatListItem={AudioStreamBasicDescription=dIIIIIIII}I}^{opaqueCMFormatDescription=}',), 'CMTimeClampToRange': (b'{_CMTime=qiIq}{_CMTime=qiIq}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}',), 'CMFormatDescriptionEqualIgnoringExtensionKeys': (b'Z^{opaqueCMFormatDescription=}^{opaqueCMFormatDescription=}@@',), 'CMSampleBufferIsValid': (b'Z^{opaqueCMSampleBuffer=}',), 'CMAudioSampleBufferCreateWithPacketDescriptions': (b'i^{__CFAllocator=}^{OpaqueCMBlockBuffer=}Z^?^v^{opaqueCMFormatDescription=}q{_CMTime=qiIq}^{AudioStreamPacketDescription=qII}^^{opaqueCMSampleBuffer=}', '', {'retval': {'already_cfretained': True}, 'arguments': {8: {'c_array_length_in_arg': 6, 'type_modifier': 'n'}, 9: {'already_cfretained': True, 'type_modifier': 'o'}, 3: {'callable': {'retval': {'type': b'i'}, 'arguments': {0: {'type': b'^{opaqueCMSampleBuffer=}'}, 1: {'type': b'^v'}}}}}}), 'CMBufferQueueGetMinDecodeTimeStamp': (b'{_CMTime=qiIq}^{opaqueCMBufferQueue=}',), 'CMMemoryPoolFlush': (b'v^{OpaqueCMMemoryPool=}',), 'CMMetadataFormatDescriptionGetIdentifiers': (b'^{__CFArray=}^{opaqueCMFormatDescription=}',), 'CMVideoFormatDescriptionCreateForImageBuffer': (b'i^{__CFAllocator=}^{__CVBuffer=}^^{opaqueCMFormatDescription=}', '', {'retval': {'already_cfretained': True}, 'arguments': {2: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMAudioFormatDescriptionGetFormatList': (b'^{AudioFormatListItem={AudioStreamBasicDescription=dIIIIIIII}I}^{opaqueCMFormatDescription=}^Q', '', {'retval': {'c_array_length_in_arg': 1}, 'arguments': {1: {'type_modifier': 'o'}}}), 'CMSampleBufferGetFormatDescription': (b'^{opaqueCMFormatDescription=}^{opaqueCMSampleBuffer=}',), 'CMTextFormatDescriptionCopyAsBigEndianTextDescriptionBlockBuffer': (b'i^{__CFAllocator=}^{opaqueCMFormatDescription=}^{__CFString=}^^{OpaqueCMBlockBuffer=}', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMSampleBufferGetOutputSampleTimingInfoArray': (b'i^{opaqueCMSampleBuffer=}q^{_CMSampleTimingInfo={_CMTime=qiIq}{_CMTime=qiIq}{_CMTime=qiIq}}^q', '', {'arguments': {2: {'c_array_length_in_arg': 1, 'type_modifier': 'o'}, 3: {'type_modifier': 'o'}}}), 'CMVideoFormatDescriptionGetHEVCParameterSetAtIndex': (b'i^{opaqueCMFormatDescription=}Q^^C^Q^Q^i',), 'CMTimebaseSetTime': (b'i^{OpaqueCMTimebase=}{_CMTime=qiIq}',), 'CMVideoFormatDescriptionGetH264ParameterSetAtIndex': (b'i^{opaqueCMFormatDescription=}Q^^C^Q^Q^i',), 'CMMetadataDataTypeRegistryGetConformingDataTypes': (b'^{__CFArray=}^{__CFString=}',), 'CMBufferQueueCreate': (b'i^{__CFAllocator=}q^{_CMBufferCallbacks=I^v^?^?^?^?^?^{__CFString=}^?}^^{opaqueCMBufferQueue=}', '', {'retval': {'already_cfretained': True}}), 'CMSyncGetTime': (b'{_CMTime=qiIq}@',), 'CMAudioFormatDescriptionCreateFromBigEndianSoundDescriptionData': (b'i^{__CFAllocator=}^CQ^{__CFString=}^^{opaqueCMFormatDescription=}', '', {'retval': {'already_cfretained': True}, 'arguments': {1: {'c_array_length_in_arg': 2, 'type_modifier': 'n'}, 4: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMMetadataDataTypeRegistryDataTypeIsRegistered': (b'Z^{__CFString=}',), 'CMAudioSampleBufferCreateReadyWithPacketDescriptions': (b'i^{__CFAllocator=}^{OpaqueCMBlockBuffer=}^{opaqueCMFormatDescription=}q{_CMTime=qiIq}^{AudioStreamPacketDescription=qII}^^{opaqueCMSampleBuffer=}', '', {'retval': {'already_cfretained': True}, 'arguments': {5: {'c_array_length_in_arg': 3, 'type_modifier': 'n'}, 6: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMSampleBufferGetOutputDuration': (b'{_CMTime=qiIq}^{opaqueCMSampleBuffer=}',), 'CMVideoFormatDescriptionGetPresentationDimensions': (b'{CGSize=dd}^{opaqueCMFormatDescription=}ZZ',), 'CMTimeMake': (b'{_CMTime=qiIq}qi',), 'CMTimebaseNotificationBarrier': (b'i^{OpaqueCMTimebase=}',), 'CMTimebaseSetTimerDispatchSourceNextFireTime': (b'i^{OpaqueCMTimebase=}@{_CMTime=qiIq}I',), 'CMClockGetTime': (b'{_CMTime=qiIq}^{OpaqueCMClock=}',), 'CMSampleBufferCreateCopyWithNewTiming': (b'i^{__CFAllocator=}^{opaqueCMSampleBuffer=}q^{_CMSampleTimingInfo={_CMTime=qiIq}{_CMTime=qiIq}{_CMTime=qiIq}}^^{opaqueCMSampleBuffer=}', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'c_array_length_in_arg': 2, 'type_modifier': 'n'}, 4: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMTimebaseSetMasterTimebase': (b'i^{OpaqueCMTimebase=}^{OpaqueCMTimebase=}',), 'CMTimebaseSetMasterClock': (b'i^{OpaqueCMTimebase=}^{OpaqueCMClock=}',), 'CMTimeRangeCopyAsDictionary': (b'^{__CFDictionary=}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}^{__CFAllocator=}', '', {'retval': {'already_cfretained': True}}), 'CMTimeMultiplyByFloat64': (b'{_CMTime=qiIq}{_CMTime=qiIq}d',), 'CMBlockBufferAssureBlockMemory': (b'i^{OpaqueCMBlockBuffer=}',), 'CMAudioDeviceClockCreate': (b'i^{__CFAllocator=}^{__CFString=}^^{OpaqueCMClock=}', '', {'retval': {'already_cfretained': True}, 'arguments': {2: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMSampleBufferGetTotalSampleSize': (b'Q^{opaqueCMSampleBuffer=}',), 'CMClockInvalidate': (b'v^{OpaqueCMClock=}',), 'CMTimebaseAddTimer': (b'i^{OpaqueCMTimebase=}^{__CFRunLoopTimer=}^{__CFRunLoop=}',), 'CMTimeRangeGetUnion': (b'{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}',), 'CMSampleBufferGetPresentationTimeStamp': (b'{_CMTime=qiIq}^{opaqueCMSampleBuffer=}',), 'CMClosedCaptionFormatDescriptionCopyAsBigEndianClosedCaptionDescriptionBlockBuffer': (b'i^{__CFAllocator=}^{opaqueCMFormatDescription=}^{__CFString=}^^{OpaqueCMBlockBuffer=}', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMBlockBufferAccessDataBytes': (b'i^{OpaqueCMBlockBuffer=}QQ^v^^c', '', {'suggestion': 'Use CMBlockBufferCopyDataBytes'}), 'CMTimeMappingCopyDescription': (b'^{__CFString=}^{__CFAllocator=}{_CMTimeMapping={_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}}', '', {'retval': {'already_cfretained': True}}), 'CMAudioFormatDescriptionCreateSummary': (b'i^{__CFAllocator=}^{__CFArray=}I^^{opaqueCMFormatDescription=}', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMAudioFormatDescriptionCreateFromBigEndianSoundDescriptionBlockBuffer': (b'i^{__CFAllocator=}^{OpaqueCMBlockBuffer=}^{__CFString=}^^{opaqueCMFormatDescription=}', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMSampleBufferCreateForImageBuffer': (b'i^{__CFAllocator=}^{__CVBuffer=}Z^?^v^{opaqueCMFormatDescription=}^{_CMSampleTimingInfo={_CMTime=qiIq}{_CMTime=qiIq}{_CMTime=qiIq}}^^{opaqueCMSampleBuffer=}', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'callable': {'retval': {'type': b'i'}, 'arguments': {0: {'type': b'^{opaqueCMSampleBuffer=}'}, 1: {'type': b'^v'}}}}, 6: {'type_modifier': 'n'}, 7: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMAudioFormatDescriptionCreate': (b'i^{__CFAllocator=}^{AudioStreamBasicDescription=dIIIIIIII}Q^{AudioChannelLayout=III[1{AudioChannelDescription=II[3f]}]}Q^v^{__CFDictionary=}^^{opaqueCMFormatDescription=}', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'type_modifier': 'n'}, 5: {'c_array_length_in_arg': 4, 'type_modifier': 'n'}, 7: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMSampleBufferGetOutputPresentationTimeStamp': (b'{_CMTime=qiIq}^{opaqueCMSampleBuffer=}',), 'CMBufferQueueGetCallbacksForSampleBuffersSortedByOutputPTS': (b'^{_CMBufferCallbacks=I^v^?^?^?^?^?^{__CFString=}^?}',), 'CMVideoFormatDescriptionCreate': (b'i^{__CFAllocator=}Iii^{__CFDictionary=}^^{opaqueCMFormatDescription=}', '', {'retval': {'already_cfretained': True}, 'arguments': {5: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMTimeRangeContainsTime': (b'Z{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}{_CMTime=qiIq}',), 'CMTimeCopyAsDictionary': (b'^{__CFDictionary=}{_CMTime=qiIq}^{__CFAllocator=}', '', {'retval': {'already_cfretained': True}}), 'CMMetadataFormatDescriptionCreateByMergingMetadataFormatDescriptions': (b'i^{__CFAllocator=}^{opaqueCMFormatDescription=}^{opaqueCMFormatDescription=}^^{opaqueCMFormatDescription=}', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMTimebaseCopyMasterTimebase': (b'^{OpaqueCMTimebase=}^{OpaqueCMTimebase=}', '', {'retval': {'already_cfretained': True}}), 'CMVideoFormatDescriptionCopyAsBigEndianImageDescriptionBlockBuffer': (b'i^{__CFAllocator=}^{opaqueCMFormatDescription=}I^{__CFString=}^^{OpaqueCMBlockBuffer=}', '', {'retval': {'already_cfretained': True}, 'arguments': {4: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMFormatDescriptionEqual': (b'Z^{opaqueCMFormatDescription=}^{opaqueCMFormatDescription=}',), 'CMTimebaseSetAnchorTime': (b'i^{OpaqueCMTimebase=}{_CMTime=qiIq}{_CMTime=qiIq}',), 'CMSimpleQueueReset': (b'i^{opaqueCMSimpleQueue=}',), 'CMSampleBufferGetOutputDecodeTimeStamp': (b'{_CMTime=qiIq}^{opaqueCMSampleBuffer=}',), 'CMTimebaseGetTypeID': (b'Q',), 'CMSampleBufferCreateReady': (b'i^{__CFAllocator=}^{OpaqueCMBlockBuffer=}^{opaqueCMFormatDescription=}qq^{_CMSampleTimingInfo={_CMTime=qiIq}{_CMTime=qiIq}{_CMTime=qiIq}}q^Q^^{opaqueCMSampleBuffer=}', '', {'retval': {'already_cfretained': True}, 'arguments': {8: {'already_cfretained': True, 'type_modifier': 'o'}, 5: {'c_array_length_in_arg': 4, 'type_modifier': 'n'}, 7: {'c_array_length_in_arg': 6, 'type_modifier': 'n'}}}), 'CMTimeShow': (b'v{_CMTime=qiIq}',), 'CMSampleBufferSetInvalidateCallback': (b'i^{opaqueCMSampleBuffer=}^?Q', '', {'arguments': {1: {'callable': {'retval': {'type': b'v'}, 'arguments': {0: {'type': b'^{opaqueCMSampleBuffer=}'}, 1: {'type': b'Q'}}}}}}), 'CMBufferQueueResetWithCallback': (b'i^{opaqueCMBufferQueue=}^?^v', '', {'arguments': {1: {'callable': {'retval': {'type': b'v'}, 'arguments': {0: {'type': b'@'}, 1: {'type': b'^v'}}}, 'callable_retained': False}}}), 'CMTimeMakeWithEpoch': (b'{_CMTime=qiIq}qiq',), 'CMTimeCodeFormatDescriptionGetTimeCodeFlags': (b'I^{opaqueCMFormatDescription=}',), 'CMClosedCaptionFormatDescriptionCreateFromBigEndianClosedCaptionDescriptionBlockBuffer': (b'i^{__CFAllocator=}^{OpaqueCMBlockBuffer=}^{__CFString=}^^{opaqueCMFormatDescription=}', '', {'retval': {'already_cfretained': True}, 'arguments': {3: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMVideoFormatDescriptionGetCleanAperture': (b'{CGRect={CGPoint=dd}{CGSize=dd}}^{opaqueCMFormatDescription=}Z',), 'CMSwapBigEndianTimeCodeDescriptionToHost': (b'i^CQ', '', {'arguments': {0: {'c_array_length_in_arg': 1, 'type_modifier': 'N'}}}), 'CMTimebaseAddTimerDispatchSource': (b'i^{OpaqueCMTimebase=}@',), 'CMTimeMinimum': (b'{_CMTime=qiIq}{_CMTime=qiIq}{_CMTime=qiIq}',), 'CMAudioFormatDescriptionGetChannelLayout': (b'^{AudioChannelLayout=III[1{AudioChannelDescription=II[3f]}]}^{opaqueCMFormatDescription=}^Q', '', {'retval': {'c_array_length_in_arg': 1}, 'arguments': {1: {'type_modifier': 'o'}}}), 'CMTextFormatDescriptionGetDisplayFlags': (b'i^{opaqueCMFormatDescription=}^I', '', {'arguments': {1: {'type_modifier': 'o'}}}), 'CMSimpleQueueGetTypeID': (b'Q',), 'CMTimeMaximum': (b'{_CMTime=qiIq}{_CMTime=qiIq}{_CMTime=qiIq}',), 'CMSampleBufferCreateWithMakeDataReadyHandler': (b'i^{__CFAllocator=}^{OpaqueCMBlockBuffer=}Z^{OpaqueCMFormatDescription=}ll^{_CMSampleTimingInfo={_CMTime=qiIq}{_CMTime=qiIq}{_CMTime=qiIq}}^^{opaqueCMSampleBuffer=}@?^^{opaqueCMSampleBuffer=}@?', '', {'retval': {'already_cfretained': True}, 'arguments': {8: {'callable': {'retval': {'type': b'i'}, 'arguments': {0: {'type': '^v'}, 1: {'type': '^{OpaqueCMSampleBuffer=}'}}}}, 6: {'c_array_length_in_arg': 5, 'type_modifier': 'n'}, 7: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMTimeCodeFormatDescriptionCreate': (b'i^{__CFAllocator=}I{_CMTime=qiIq}II^{__CFDictionary=}^^{opaqueCMFormatDescription=}', '', {'retval': {'already_cfretained': True}, 'arguments': {6: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMRemoveAttachment': (b'v@^{__CFString=}',), 'CMPropagateAttachments': (b'v@@',), 'CMBlockBufferCreateWithBufferReference': (b'i^{__CFAllocator=}^{OpaqueCMBlockBuffer=}QQI^^{OpaqueCMBlockBuffer=}', '', {'retval': {'already_cfretained': True}, 'arguments': {5: {'already_cfretained': True, 'type_modifier': 'o'}}}), 'CMRemoveAllAttachments': (b'v@',), 'CMTimebaseGetRate': (b'd^{OpaqueCMTimebase=}',), 'CMSampleBufferGetSampleSizeArray': (b'i^{opaqueCMSampleBuffer=}q^Q^q', '', {'arguments': {2: {'c_array_length_in_arg': 1, 'type_modifier': 'o'}, 3: {'type_modifier': 'o'}}}), 'CMTimebaseSetTimerToFireImmediately': (b'i^{OpaqueCMTimebase=}^{__CFRunLoopTimer=}',), 'CMBufferQueueIsAtEndOfData': (b'Z^{opaqueCMBufferQueue=}',)}
aliases = {'CMSubtitleFormatDescriptionGetFormatType': 'CMFormatDescriptionGetMediaSubType', 'COREMEDIA_DECLARE_BRIDGED_TYPES': 'COREMEDIA_TRUE', 'CMVideoFormatDescriptionGetCodecType': 'CMFormatDescriptionGetMediaSubType', 'COREMEDIA_DECLARE_NULLABILITY_BEGIN_END': 'COREMEDIA_TRUE', 'kCMFormatDescriptionExtension_YCbCrMatrix': 'kCVImageBufferYCbCrMatrixKey', 'kCMFormatDescriptionExtension_FieldCount': 'kCVImageBufferFieldCountKey', 'CM_RETURNS_NOT_RETAINED_PARAMETER': 'CF_RETURNS_NOT_RETAINED', 'kCMFormatDescriptionExtension_GammaLevel': 'kCVImageBufferGammaLevelKey', 'kCMFormatDescriptionChromaLocation_Bottom': 'kCVImageBufferChromaLocation_Bottom', 'kCMFormatDescriptionKey_CleanApertureVerticalOffset': 'kCVImageBufferCleanApertureVerticalOffsetKey', 'CM_RETURNS_RETAINED': 'CF_RETURNS_RETAINED', 'kCMFormatDescriptionYCbCrMatrix_SMPTE_240M_1995': 'kCVImageBufferYCbCrMatrix_SMPTE_240M_1995', 'kCMFormatDescriptionExtension_ColorPrimaries': 'kCVImageBufferColorPrimariesKey', 'kCMFormatDescriptionYCbCrMatrix_ITU_R_601_4': 'kCVImageBufferYCbCrMatrix_ITU_R_601_4', 'kCMFormatDescriptionColorPrimaries_SMPTE_C': 'kCVImageBufferColorPrimaries_SMPTE_C', 'COREMEDIA_DECLARE_RELEASES_ARGUMENT': 'COREMEDIA_TRUE', 'CM_NULLABLE': '__nullable', 'COREMEDIA_DECLARE_RETURNS_NOT_RETAINED_ON_PARAMETERS': 'COREMEDIA_TRUE', 'kCMFormatDescriptionChromaLocation_Left': 'kCVImageBufferChromaLocation_Left', 'kCMFormatDescriptionTransferFunction_UseGamma': 'kCVImageBufferTransferFunction_UseGamma', 'kCMTimeRoundingMethod_Default': 'kCMTimeRoundingMethod_RoundHalfAwayFromZero', 'kCMFormatDescriptionKey_PixelAspectRatioVerticalSpacing': 'kCVImageBufferPixelAspectRatioVerticalSpacingKey', 'CM_NONNULL': '__nonnull', 'kCMFormatDescriptionKey_PixelAspectRatioHorizontalSpacing': 'kCVImageBufferPixelAspectRatioHorizontalSpacingKey', 'kCMVideoCodecType_422YpCbCr8': 'kCMPixelFormat_422YpCbCr8', 'kCMFormatDescriptionExtension_VerbatimImageDescription': 'kCMFormatDescriptionExtension_VerbatimSampleDescription', 'kCMFormatDescriptionExtension_ChromaLocationTopField': 'kCVImageBufferChromaLocationTopFieldKey', 'kCMFormatDescriptionExtension_PixelAspectRatio': 'kCVImageBufferPixelAspectRatioKey', 'COREMEDIA_CMBASECLASS_VERSION_IS_POINTER_ALIGNED': 'COREMEDIA_FALSE', 'CM_RELEASES_ARGUMENT': 'CF_RELEASES_ARGUMENT', 'COREMEDIA_DECLARE_RETURNS_RETAINED_BLOCK': 'COREMEDIA_TRUE', 'kCMFormatDescriptionTransferFunction_SMPTE_240M_1995': 'kCVImageBufferTransferFunction_SMPTE_240M_1995', 'kCMFormatDescriptionExtension_ChromaLocationBottomField': 'kCVImageBufferChromaLocationBottomFieldKey', 'kCMFormatDescriptionExtension_TransferFunction': 'kCVImageBufferTransferFunctionKey', 'kCMTimebaseFarFutureCFAbsoluteTime': 'kCMTimebaseVeryLongCFTimeInterval', 'CM_RETURNS_RETAINED_PARAMETER': 'CF_RETURNS_RETAINED', 'kCMFormatDescriptionKey_CleanApertureHorizontalOffset': 'kCVImageBufferCleanApertureHorizontalOffsetKey', 'kCMFormatDescriptionTransferFunction_ITU_R_709_2': 'kCVImageBufferTransferFunction_ITU_R_709_2', 'kCMFormatDescriptionColorPrimaries_EBU_3213': 'kCVImageBufferColorPrimaries_EBU_3213', 'COREMEDIA_DECLARE_NULLABILITY': 'COREMEDIA_TRUE', 'kCMFormatDescriptionKey_CleanApertureWidth': 'kCVImageBufferCleanApertureWidthKey', 'CM_RETURNS_RETAINED_BLOCK': 'DISPATCH_RETURNS_RETAINED_BLOCK', 'kCMFormatDescriptionExtension_FieldDetail': 'kCVImageBufferFieldDetailKey', 'kCMFormatDescriptionFieldDetail_SpatialFirstLineLate': 'kCVImageBufferFieldDetailSpatialFirstLineLate', 'COREMEDIA_DECLARE_RETURNS_RETAINED': 'COREMEDIA_TRUE', 'kCMFormatDescriptionColorPrimaries_ITU_R_709_2': 'kCVImageBufferColorPrimaries_ITU_R_709_2', 'COREMEDIA_USE_ALIGNED_CMBASECLASS_VERSION': 'COREMEDIA_TRUE', 'kCMFormatDescriptionChromaLocation_DV420': 'kCVImageBufferChromaLocation_DV420', 'COREMEDIA_DECLARE_RETURNS_RETAINED_ON_PARAMETERS': 'COREMEDIA_TRUE', 'kCMFormatDescriptionChromaLocation_TopLeft': 'kCVImageBufferChromaLocation_TopLeft', 'kCMFormatDescriptionFieldDetail_SpatialFirstLineEarly': 'kCVImageBufferFieldDetailSpatialFirstLineEarly', 'kCMFormatDescriptionFieldDetail_TemporalBottomFirst': 'kCVImageBufferFieldDetailTemporalBottomFirst', 'kCMFormatDescriptionExtension_CleanAperture': 'kCVImageBufferCleanApertureKey', 'kCMFormatDescriptionYCbCrMatrix_ITU_R_709_2': 'kCVImageBufferYCbCrMatrix_ITU_R_709_2', 'COREMEDIA_USE_DERIVED_ENUMS_FOR_CONSTANTS': 'COREMEDIA_TRUE', 'kCMFormatDescriptionKey_CleanApertureHeight': 'kCVImageBufferCleanApertureHeightKey', 'kCMFormatDescriptionFieldDetail_TemporalTopFirst': 'kCVImageBufferFieldDetailTemporalTopFirst', 'kCMFormatDescriptionChromaLocation_Center': 'kCVImageBufferChromaLocation_Center', 'CMITEMCOUNT_MAX': 'INTPTR_MAX', 'kCMFormatDescriptionChromaLocation_BottomLeft': 'kCVImageBufferChromaLocation_BottomLeft', 'kCMFormatDescriptionChromaLocation_Top': 'kCVImageBufferChromaLocation_Top'}
cftypes=[('CMBufferQueueRef', b'^{opaqueCMBufferQueue=}', 'CMBufferQueueGetTypeID', None), ('CMMemoryPoolRef', b'^{opaqueCMMemoryPool=}', 'CMMemoryPoolGetTypeID', None), ('CMFormatDescriptionRef', b'^{opaqueCMFormatDescription=}', 'CMFormatDescriptionGetTypeID', None), ('CMTimebaseRef', b'^{opaqueCMTimebase=}', 'CMTimebaseGetTypeID', None), ('CMSimpleQueueRef', b'^{opaqueCMSimpleQueue=}', 'CMSimpleQueueGetTypeID', None), ('CMClockRef', b'^{opaqueCMClock=}', 'CMClockGetTypeID', None), ('CMBlockBufferRef', b'^{opaqueCMBlockBuffer=}', 'CMBlockBufferGetTypeID', None), ('CMSimpleQueueef', b'^{opaqueCMSimpleQueue}', 'CMSimpleQueueetTypeID', None), ('CMSampleBufferRef', b'^{opaqueCMSampleBuffer=}', 'CMSampleBufferGetTypeID', None), ('CMSampleBufferrRef', b'^{opaqueCMSampleBufferr=}', 'CMSampleBufferrGetTypeID', None)]
misc.update({'CMBufferQueueTriggerToken': objc.createOpaquePointerType('CMBufferQueueTriggerToken', b'^{opaqueCMBufferQueueTriggerToken=}')})
expressions = {'kCMTimebaseVeryLongCFTimeInterval': '(CFTimeInterval)(256.0 * 365.0 * 24.0 * 60.0 * 60.0)'}

# END OF FILE



import CoreMedia
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestCMMetadata(TestCase):
    def test_constants(self):
        self.assertEqual(CoreMedia.kCMMetadataIdentifierError_AllocationFailed, -16300)
        self.assertEqual(
            CoreMedia.kCMMetadataIdentifierError_RequiredParameterMissing, -16301
        )
        self.assertEqual(CoreMedia.kCMMetadataIdentifierError_BadKey, -16302)
        self.assertEqual(CoreMedia.kCMMetadataIdentifierError_BadKeyLength, -16303)
        self.assertEqual(CoreMedia.kCMMetadataIdentifierError_BadKeyType, -16304)
        self.assertEqual(CoreMedia.kCMMetadataIdentifierError_BadNumberKey, -16305)
        self.assertEqual(CoreMedia.kCMMetadataIdentifierError_BadKeySpace, -16306)
        self.assertEqual(CoreMedia.kCMMetadataIdentifierError_BadIdentifier, -16307)
        self.assertEqual(
            CoreMedia.kCMMetadataIdentifierError_NoKeyValueAvailable, -16308
        )

        self.assertEqual(
            CoreMedia.kCMMetadataDataTypeRegistryError_AllocationFailed, -16310
        )
        self.assertEqual(
            CoreMedia.kCMMetadataDataTypeRegistryError_RequiredParameterMissing, -16311
        )
        self.assertEqual(
            CoreMedia.kCMMetadataDataTypeRegistryError_BadDataTypeIdentifier, -16312
        )
        self.assertEqual(
            CoreMedia.kCMMetadataDataTypeRegistryError_DataTypeAlreadyRegistered, -16313
        )
        self.assertEqual(
            CoreMedia.kCMMetadataDataTypeRegistryError_RequiresConformingBaseType,
            -16314,
        )
        self.assertEqual(
            CoreMedia.kCMMetadataDataTypeRegistryError_MultipleConformingBaseTypes,
            -16315,
        )

    @min_os_level("10.10")
    def test_constants10_10(self):
        self.assertIsInstance(CoreMedia.kCMMetadataKeySpace_QuickTimeUserData, str)
        self.assertIsInstance(CoreMedia.kCMMetadataKeySpace_ISOUserData, str)
        self.assertIsInstance(CoreMedia.kCMMetadataKeySpace_QuickTimeMetadata, str)
        self.assertIsInstance(CoreMedia.kCMMetadataKeySpace_iTunes, str)
        self.assertIsInstance(CoreMedia.kCMMetadataKeySpace_ID3, str)
        self.assertIsInstance(CoreMedia.kCMMetadataKeySpace_Icy, str)
        self.assertIsInstance(
            CoreMedia.kCMMetadataIdentifier_QuickTimeMetadataLocation_ISO6709, str
        )
        self.assertIsInstance(
            CoreMedia.kCMMetadataIdentifier_QuickTimeMetadataDirection_Facing, str
        )
        self.assertIsInstance(
            CoreMedia.kCMMetadataIdentifier_QuickTimeMetadataPreferredAffineTransform,
            str,
        )

        self.assertIsInstance(CoreMedia.kCMMetadataBaseDataType_RawData, str)
        self.assertIsInstance(CoreMedia.kCMMetadataBaseDataType_UTF8, str)
        self.assertIsInstance(CoreMedia.kCMMetadataBaseDataType_UTF16, str)
        self.assertIsInstance(CoreMedia.kCMMetadataBaseDataType_GIF, str)
        self.assertIsInstance(CoreMedia.kCMMetadataBaseDataType_JPEG, str)
        self.assertIsInstance(CoreMedia.kCMMetadataBaseDataType_PNG, str)
        self.assertIsInstance(CoreMedia.kCMMetadataBaseDataType_BMP, str)
        self.assertIsInstance(CoreMedia.kCMMetadataBaseDataType_Float32, str)
        self.assertIsInstance(CoreMedia.kCMMetadataBaseDataType_Float64, str)
        self.assertIsInstance(CoreMedia.kCMMetadataBaseDataType_SInt8, str)
        self.assertIsInstance(CoreMedia.kCMMetadataBaseDataType_SInt16, str)
        self.assertIsInstance(CoreMedia.kCMMetadataBaseDataType_SInt32, str)
        self.assertIsInstance(CoreMedia.kCMMetadataBaseDataType_SInt64, str)
        self.assertIsInstance(CoreMedia.kCMMetadataBaseDataType_UInt8, str)
        self.assertIsInstance(CoreMedia.kCMMetadataBaseDataType_UInt16, str)
        self.assertIsInstance(CoreMedia.kCMMetadataBaseDataType_UInt32, str)
        self.assertIsInstance(CoreMedia.kCMMetadataBaseDataType_UInt64, str)
        self.assertIsInstance(CoreMedia.kCMMetadataBaseDataType_PointF32, str)
        self.assertIsInstance(CoreMedia.kCMMetadataBaseDataType_DimensionsF32, str)
        self.assertIsInstance(CoreMedia.kCMMetadataBaseDataType_AffineTransformF64, str)
        self.assertIsInstance(
            CoreMedia.kCMMetadataDataType_QuickTimeMetadataLocation_ISO6709, str
        )
        self.assertIsInstance(
            CoreMedia.kCMMetadataDataType_QuickTimeMetadataDirection, str
        )

    @min_os_level("10.11")
    def test_constants10_11(self):
        self.assertIsInstance(
            CoreMedia.kCMMetadataIdentifier_QuickTimeMetadataVideoOrientation, str
        )

        self.assertIsInstance(CoreMedia.kCMMetadataBaseDataType_PolygonF32, str)
        self.assertIsInstance(CoreMedia.kCMMetadataBaseDataType_PolylineF32, str)
        self.assertIsInstance(CoreMedia.kCMMetadataBaseDataType_JSON, str)

    @min_os_level("10.13")
    def test_constants10_13(self):
        self.assertIsInstance(CoreMedia.kCMMetadataKeySpace_HLSDateRange, str)

    @min_os_level("10.15")
    def test_constants10_15(self):
        self.assertIsInstance(
            CoreMedia.kCMMetadataIdentifier_QuickTimeMetadataLivePhotoStillImageTransform,
            str,
        )
        self.assertIsInstance(
            CoreMedia.kCMMetadataBaseDataType_PerspectiveTransformF64, str
        )

    @min_os_level("10.15.1")
    def test_constants10_15_1(self):
        self.assertIsInstance(
            CoreMedia.kCMMetadataIdentifier_QuickTimeMetadataLivePhotoStillImageTransformReferenceDimensions,
            str,
        )

    @min_os_level("10.10")
    def test_functions10_10(self):
        self.assertArgIsOut(CoreMedia.CMMetadataCreateIdentifierForKeyAndKeySpace, 3)
        self.assertArgIsCFRetained(
            CoreMedia.CMMetadataCreateIdentifierForKeyAndKeySpace, 3
        )

        self.assertArgIsOut(CoreMedia.CMMetadataCreateKeyFromIdentifier, 2)
        self.assertArgIsCFRetained(CoreMedia.CMMetadataCreateKeyFromIdentifier, 2)

        self.assertArgIsOut(CoreMedia.CMMetadataCreateKeyFromIdentifierAsCFData, 2)
        self.assertArgIsCFRetained(
            CoreMedia.CMMetadataCreateKeyFromIdentifierAsCFData, 2
        )

        self.assertArgIsOut(CoreMedia.CMMetadataCreateKeySpaceFromIdentifier, 2)
        self.assertArgIsCFRetained(CoreMedia.CMMetadataCreateKeySpaceFromIdentifier, 2)

        CoreMedia.CMMetadataDataTypeRegistryRegisterDataType

        self.assertResultIsBOOL(
            CoreMedia.CMMetadataDataTypeRegistryDataTypeIsRegistered
        )

        CoreMedia.CMMetadataDataTypeRegistryGetDataTypeDescription
        CoreMedia.CMMetadataDataTypeRegistryGetConformingDataTypes

        self.assertResultIsBOOL(
            CoreMedia.CMMetadataDataTypeRegistryDataTypeConformsToDataType
        )

        CoreMedia.CMMetadataDataTypeRegistryGetBaseDataTypes

        self.assertResultIsBOOL(
            CoreMedia.CMMetadataDataTypeRegistryDataTypeIsBaseDataType
        )

        CoreMedia.CMMetadataDataTypeRegistryGetBaseDataTypeForConformingDataType
